@@ -1,5 +1,5 @@
 /*
- *	libetm-0.4 / misc.h - Copyright (C) Emmanuel Thomas-Maurin 2008-2011
+ *	libetm-0.4 / misc.h - Copyright (C) Emmanuel Thomas-Maurin 2008-2012
  * 	<manutm007@gmail.com>
  *
  *	- misc functions -
@@ -21,6 +21,14 @@
 #ifndef INC_LIBETM_MISC_H
 #define INC_LIBETM_MISC_H
 
-const char *lib_version(unsigned int);
-int question(const char *);
+/* get_libetm_version(	O ) = version num
+ * 			1   = copyright
+ *			2   = license 1/3
+ *			3   = license 2/3
+ *			4   = license 3/3
+ *			5   = compiled date
+ *			> 5 = NULL
+ */
+const char	*get_libetm_version(unsigned int);
+int		question(const char *);
 #endif /* INC_LIBETM_MISC_H */
