@@ -1,5 +1,5 @@
 /*
- *	libetm-0.4 / str_mem.c - Copyright (C) Emmanuel Thomas-Maurin 2008-2011
+ *	libetm-0.4 / str_mem.c - Copyright (C) Emmanuel Thomas-Maurin 2008-2012
  * 	<manutm007@gmail.com>
  *
  *	- some strings and memory management functions -
@@ -22,6 +22,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include <time.h>
+#include <ctype.h>
 #include "libetm.h"
 
 /*
@@ -116,7 +117,8 @@ void l_str_free(char *l_str)
 		free(l_str);
 	else
 		big_error_in_lib(NULL_POINTER_FREE, "l_str_free()");
-	l_str = NULL;
+	/* CODE WITH NO EFFECT
+	l_str = NULL;*/
 }
 
 /*
@@ -174,15 +176,16 @@ void free2(void *free_block)
 	else
 		big_error_in_lib(NULL_POINTER_FREE, "free2()");
 
-	free_block = NULL;
+	/* CODE WITH NO EFFECT
+	free_block = NULL;*/
 }
 
 /*
- * return size in readable format (KB, MB, GB, TB)
+ * return size in readable format (KiB, MiB, GiB, TiB)
  * *** allow up to 16 simultaneous calls ***
- * convention: we assume 2.5 MB = 2 MB + [0.5 x 1024 = 512] KB, not 500 KB
+ * convention: we assume 2.5 MiB = 2 MiB + [0.5 x 1024 = 512] KiB, not 500 KiB
  * otherwise, there is no way to express a value in the range 1000 - 1023
- * so x.y MB = x MB + 0.y MB, that is: not y x 100 KB but y x 102.4 KB
+ * so x.y MiB = x MiB + 0.y MiB, that is: not y x 100 KiB but y x 102.4 KiB
  * (isn't this a bit confusing?)
  */
 const char *readable_size(double size_bytes)
@@ -195,29 +198,29 @@ const char *readable_size(double size_bytes)
 	 * equal whereas sizes are different
 	 */
 	static char	lib_static_str[16][128];
-	unsigned long	size_KB, size_MB, size_GB, size_TB;
+	unsigned long	size_KiB, size_MiB, size_GiB, size_TiB;
 	static int	count = -1;
 
 	count++;
 	count &= 15;
 
-	size_KB = (unsigned long)(size_bytes / 1024);
-	size_MB = size_KB / 1024;
-	size_GB = size_MB / 1024;
-	size_TB = size_GB / 1024;
+	size_KiB = (unsigned long)(size_bytes / 1024);
+	size_MiB = size_KiB / 1024;
+	size_GiB = size_MiB / 1024;
+	size_TiB = size_GiB / 1024;
 
-	if (size_TB >= 1)
-		snprintf(lib_static_str[count], 128, "%ld.%ld TB",
-			size_TB, ((size_GB - size_TB * 1024) * 10) / 1024);
-	else if (size_GB >= 1)
-		snprintf(lib_static_str[count], 128, "%ld.%ld GB",
-			size_GB, ((size_MB - size_GB * 1024) * 10) / 1024);
-	else if (size_MB >= 1)
-		snprintf(lib_static_str[count], 128, "%ld.%ld MB",
-			size_MB, ((size_KB - size_MB * 1024) * 10) / 1024);
-	else if (size_KB >= 1)
-		snprintf(lib_static_str[count], 128, "%ld.%ld KB",
-			size_KB, (unsigned long)((size_bytes - size_KB * 1024)  * 10) / 1024);
+	if (size_TiB >= 1)
+		snprintf(lib_static_str[count], 128, "%ld.%ld TiB",
+			size_TiB, ((size_GiB - size_TiB * 1024) * 10) / 1024);
+	else if (size_GiB >= 1)
+		snprintf(lib_static_str[count], 128, "%ld.%ld GiB",
+			size_GiB, ((size_MiB - size_GiB * 1024) * 10) / 1024);
+	else if (size_MiB >= 1)
+		snprintf(lib_static_str[count], 128, "%ld.%ld MiB",
+			size_MiB, ((size_KiB - size_MiB * 1024) * 10) / 1024);
+	else if (size_KiB >= 1)
+		snprintf(lib_static_str[count], 128, "%ld.%ld KiB",
+			size_KiB, (unsigned long)((size_bytes - size_KiB * 1024)  * 10) / 1024);
 	else
 		snprintf(lib_static_str[count], 128, "%.0f bytes", size_bytes);
 
@@ -240,7 +243,10 @@ const char *itoa2(long int n)
 	return (const char *)lib_static_str[count];
 }
 
-void remove_char_from_str(char *str, char c)
+/*
+ * modify string in place
+ */
+char *remove_char_from_str(char *str, char c)
 {
 	int i, len = strlen(str);
 
@@ -250,6 +256,20 @@ void remove_char_from_str(char *str, char c)
 		else
 			i++;
 	}
+	return str;
+}
+
+/*
+ * modify string in place
+ */
+char *remove_trailing_whitespaces_from_str(char *str)
+{
+	int	i = strlen(str) - 1;
+
+	while (isspace((int)str[i]) && i >= 0)
+		i--;
+	str[i + 1] = '\0';
+	return str;
 }
 
 /*
