@@ -1,5 +1,5 @@
 /*
- *	libetm-0.4 / win32_specific.h - Copyright (C) Emmanuel Thomas-Maurin 2008-2011
+ *	libetm-0.4 / win32_specific.h - Copyright (C) Emmanuel Thomas-Maurin 2008-2012
  *	<manutm007@gmail.com>
  *
  *	- win32 specific functions -
@@ -21,6 +21,12 @@
 #ifndef INC_LIBETM_WIN32_SPECIFIC_H
 #define INC_LIBETM_WIN32_SPECIFIC_H
 
+#ifdef G_OS_WIN32
+# ifndef WIN32_V
+#  define WIN32_V
+# endif
+#endif
+
 #ifdef WIN32_V
 /* return NULL if error */
 const char	*get_appdata_dir();
