@@ -1,5 +1,5 @@
 /*
- *	TICKR - GTK-based Feed Reader - Copyright (C) Emmanuel Thomas-Maurin 2009-2011
+ *	TICKR - GTK-based Feed Reader - Copyright (C) Emmanuel Thomas-Maurin 2009-2012
  *	<manutm007@gmail.com>
  *
  * 	This program is free software: you can redistribute it and/or modify
@@ -16,13 +16,16 @@
  * 	along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#ifndef INC_TICKR_H
+#define INC_TICKR_H
+
 #define APP_NAME		"Tickr"
 #define APP_CMD			"tickr"
-#define APP_VERSION_NUMBER	"0.5.5"
+#define APP_VERSION_NUMBER	"0.6.0"
 #define APP_WEBSITE		"http://www.newsrssticker.com"
 #define APP_SUPPORT_WEBSITE	"http://www.newsrssticker.com/help.php"
 #define APP_DOWNLOAD_WEBSITE	"http://www.newsrssticker.com/download.php"
-#define APP_SUPPORT_EMAIL	"newsrssticker@gmail.com"/*"contact@newsrssticker.com"*/
+#define APP_SUPPORT_EMAIL	"tickrfeedreader@gmail.com"/*"contact@newsrssticker.com"*/
 
 #define _GNU_SOURCE
 #define _ISOC99_SOURCE
@@ -61,8 +64,9 @@
 # include <arpa/inet.h>
 # include <sys/select.h>
 #else
-/*# include <windows.h>*/
-# define _WIN32_WINNT	0x0501	/* win version = xp or higher */
+/* win version = xp or higher */
+# define WINVER		0x0501
+# define _WIN32_WINNT	0x0501
 # include <winsock2.h>
 # include <ws2tcpip.h>
 # include <rpcdce.h>
@@ -77,7 +81,9 @@
 #endif
 #include <libxml/parser.h>
 #include <libxml/tree.h>
-#include "../libetm-0.4.2/libetm.h"
+#include "../libetm-0.4.3/libetm.h"
+#include "tickr_socket.h"
+#include "tickr_list.h"
 
 #define	USE_GUI			TRUE	/* to implement or not gui/menu features at compile time
 					 * otherwise, cli only app */
@@ -103,10 +109,10 @@
 #define OPTION_NAME_MAXLEN	31
 #define OPTION_VALUE_MAXLEN	MAX(MAX(FILE_NAME_MAXLEN, FONT_MAXLEN), DELIMITER_MAXLEN)
 #define OPTION_MAXLEN		OPTION_NAME_MAXLEN + OPTION_VALUE_MAXLEN + 4	/* -name="value" */
-#define NOPTIONSMAX		64	/* max number of options */
-#define NURLMAX			512	/* max number of url's */
+#define N_OPTION_MAX		64	/* max number of options */
+#define N_URL_MAX		1024	/* max number of url's */
 #define NFEEDLINKANDOFFSETMAX	256	/* max number of "open-able" links per feed */
-#define LINKTAG_CHAR		'^'	/* ascii 5E - char used internally for links, removed from feed text */
+#define LINK_TAG_CHAR		'^'	/* ascii 5E - char used internally for links, removed from feed text */
 #define TMPSTR_SIZE		(2 * 1024 - 1)	/* used for most tmp strings - must be large enough */
 #ifndef G_OS_WIN32
 # define SEPARATOR_CHAR		'/'
@@ -126,7 +132,7 @@
 #define XPIXMAP_MAXWIDTH	(32 * 1024 - 1)	/* 32 K - 1 = max supported width for xpixmaps
 						 * (not 64 k - 1 as sometimes uncorrectly specified)
 						 */
-#define LINE_MAXLEN		128	/* max length of a single line (see news_render.c) */
+#define LINE_MAXLEN		128	/* max length of a single line (see tickr_render.c) */
 #define WORD_MAXLEN		32	/* max length of a word that won't get cut off */
 #if (LINE_MAXLEN <= WORD_MAXLEN)
 # error LINE_MAXLEN must be > WORD_MAXLEN
@@ -141,18 +147,18 @@
  *			/usr/share/APP_CMD/pixmpas/
  *			/home/<user_name>/.APP_CMD/
  *
- * win32 version:	C:\Program files\APP_NAME	(also location for pixmaps)
- *			C:\...\Application Data\APP_NAME
+ * win32 version:	C:\Program files\APP_NAME\	(also location for pixmaps)
+ *			C:\...\Application Data\APP_NAME\
  */
 #ifndef G_OS_WIN32
-# define NEWS_DIR_NAME		"."APP_CMD
+# define TICKR_DIR_NAME		"."APP_CMD
 #else
-# define NEWS_DIR_NAME		APP_NAME
+# define TICKR_DIR_NAME		APP_NAME
 #endif
-#define CONFIGFILE		APP_CMD"-conf"
-#define URLLIST			APP_CMD"-url-list"
-#define RESOURCEDUMP		APP_CMD"-resrc-dump"
-#define XMLDUMP			APP_CMD"-xml-dump"
+#define CONFIG_FILE		APP_CMD"-conf"
+#define URL_LIST_FILE		APP_CMD"-url-list"
+#define RESOURCE_DUMP		APP_CMD"-resrc-dump"
+#define XML_DUMP		APP_CMD"-xml-dump"
 #define TMP1			"tmp1"
 #define TMP2			"tmp2"
 #ifndef G_OS_WIN32
@@ -160,9 +166,11 @@
 # define STD_ERR		stderr
 #else
 # define STD_OUT		stdout_fp
-# define STDOUT_FILENAME	"stdout.txt"
+# define STDOUT_FILENAME1	"stdout1.txt"
+# define STDOUT_FILENAME2	"stdout2.txt"
 # define STD_ERR		stderr_fp
-# define STDERR_FILENAME	"stderr.txt"
+# define STDERR_FILENAME1	"stderr1.txt"
+# define STDERR_FILENAME2	"stderr2.txt"
 #endif
 #ifndef G_OS_WIN32
 # define INSTALL_PATH		"/usr/share/"APP_CMD
@@ -170,8 +178,8 @@
 #else
 # define IMAGES_PATH		APP_NAME	/* actually not a path but a dir name */
 #endif
-#define NEWS_ICON		APP_CMD"-icon.png"
-#define NEWS_LOGO		APP_CMD"-logo.png"
+#define TICKR_ICON		APP_CMD"-icon.png"
+#define TICKR_LOGO		APP_CMD"-logo.png"
 #define RSS_ICON		APP_CMD"-rss-icon.png"
 
 /* default config values */
@@ -210,7 +218,6 @@
 #define RSSDESCRIPTION		'n'
 #define RSSDESCRIPTIONDELIMITER	"        -        "
 #define NITEMSPERFEED		5
-/*#define READINLOOP		'y'*/
 #define STRIPHTMLTAGS		'y'
 #define UPPERCASETEXT		'n'
 #define HOMEFEED		"http://newsrss.bbc.co.uk/rss/newsonline_world_edition/front_page/rss.xml"
@@ -273,7 +280,13 @@ typedef enum {
 typedef enum {
 	WIN_WITH_SPINNER_OPEN,
 	WIN_WITH_SPINNER_CLOSE
-} spinner_win_mode;
+} win_with_spinner_mode;
+
+typedef enum {
+	WIN_WITH_PROGRESS_BAR_OPEN,
+	WIN_WITH_PROGRESS_BAR_PULSE,
+	WIN_WITH_PROGRESS_BAR_CLOSE
+} win_with_progress_bar_mode;
 
 typedef enum {
 	AUTH_PAGE,
@@ -382,7 +395,6 @@ typedef struct {
 	char		rss_description;
 	char		rss_description_delimiter[DELIMITER_MAXLEN + 1];
 	int		n_items_per_feed;
-	/*char		read_in_loop;*/
 	char		strip_html_tags;
 	char		upper_case_text;
 	char		homefeed[FILE_NAME_MAXLEN + 1];
@@ -412,7 +424,7 @@ typedef struct {
 
 /* error codes */
 typedef enum {
-	OK = LIBETM_LASTERRORCODE + 1,
+	OK = SOCKET_LASTERRORCODE + 1,
 
 	RESOURCE_ERROR,
 	RESOURCE_UNSPECIFIED,
@@ -433,8 +445,6 @@ typedef enum {
 	FEED_ERROR,
 	FEED_EMPTY,
 	FEED_UNPARSABLE,
-	FEED_CANTCREATEXMLDUMP,
-	FEED_CANTREADXMLDUMP,
 	RSS_NO_ITEM_ELEMENT,
 	ATOM_NO_ENTRY_ELEMENT,
 	FEED_DOWNLOAD_ERROR,
@@ -449,7 +459,9 @@ typedef enum {
 	RENDER_CREATE_CAIRO_IMAGE_SURFACE_ERROR,
 	RENDER_OTHER_ERROR,
 
+	FLIST_ERROR,
 	LOAD_URL_LIST_ERROR,
+	LOAD_URL_LIST_EMPTY_LIST,
 	SAVE_URL_LIST_ERROR,
 
 	CREATE_FILE_ERROR,
@@ -461,18 +473,6 @@ typedef enum {
 
 	OPML_ERROR,
 
-	SOCK_ERROR,
-	SOCK_CANT_CONNECT,
-	SOCK_SHOULD_BE_CLOSED,
-
-	SELECT_ERROR,
-	SELECT_TIMED_OUT,
-	SELECT_TRUE,
-	SELECT_FALSE,
-
-	SEND_ERROR,
-	RECV_ERROR,
-	CONNECTION_CLOSED_BY_SERVER,
 	CONNECT_TOO_MANY_ERRORS,
 
 	HTTP_ERROR,
@@ -497,33 +497,36 @@ typedef enum {
 	WIN32V_ERROR
 } tickr_error_code;
 
-/* news_main.c */
-void		check_main_win_always_on_top();
-gboolean	params_have_been_changed(Params *, int);
-void		check_time_load_resource();
+/* tickr_main.c */
 TickerEnv	*get_ticker_env();
 Resource	*get_resource();
+FList		*get_feed_list();
+void		set_feed_list(FList *);
+FList		*get_feed_selection();
+void		set_feed_selection(FList *);
 Params		*get_params();
-char		**get_get_selected_url();
 int		get_instance_id();
+void		check_main_win_always_on_top();
+gboolean	params_have_been_changed(Params *, int);
 gint		update_everything();
 
-/* news_resource.c */
+/* tickr_resource.c */
+int		build_feed_selection_from_feed_list();
 void		current_feed();
-gboolean	previous_feed();
-gboolean	next_feed();
 void		first_feed();
 void		last_feed();
-int		load_resource(Resource *, char **);
+gboolean	previous_feed();
+gboolean	next_feed();
+int		load_resource(Resource *, FList *);
 int		format_resource(Resource *);
-void		set_news_icon_to_dialog(GtkWindow *);
+void		set_tickr_icon_to_dialog(GtkWindow *);
 FILE		*open_new_datafile_with_name(const char *, const char *);
-const char	*get_datafile_full_name_from_name(const char *);
-const char	*get_imagefile_full_name_from_name(const char *);
-const char	*get_datadir_full_path();
-const char	*usr_home_dir();
+char		*get_datafile_full_name_from_name(const char *);
+char		*get_imagefile_full_name_from_name(const char *);
+char		*get_datadir_full_path();
+char		*usr_home_dir();
 
-/* news_render.c */
+/* tickr_render.c */
 cairo_surface_t *render_stream_to_surface(FILE *, FeedLinkAndOffset *, const Params *, int *);
 char		*stream_to_htext(FILE *, char *, PangoLayout *, const Params *, int *);
 char 		*void_stream_to_htext(char *, PangoLayout *);
@@ -533,7 +536,7 @@ gint		get_layout_width(PangoLayout *, const char *);
 gint		get_layout_height(PangoLayout *, const char *);
 void		pango_layout_get_pixel_size2(PangoLayout *, int *, int *);
 
-/* news_params.c */
+/* tickr_params.c */
 void		set_default_options(Params *);
 int		get_config_file_options(Params *);
 int		parse_options_array(Params *, int, const char *[]);
@@ -544,11 +547,11 @@ const char	*get_hexstr_from_gdk_color(const GdkColor *, const guint16 *);
 void		split_font(const char *, char *, char *);
 void		compact_font(char *, const char *, const char *);
 
-/* news_clock.c */
+/* tickr_clock.c */
 void		display_time(const Params *);
 gint		get_clock_width(const Params *);
 
-/* news_rss.c */
+/* tickr_feedparser.c */
 int		get_feed(Resource *, const Params *);
 int		parse_rss20_xml_file(FILE *, const char *, FeedLinkAndOffset *link_and_offset,\
 			const Params *);
@@ -568,44 +571,32 @@ void		get_atom_selected_elements2(xmlNode *, xmlDoc *,\
 int		get_feed_info(const char *, char *, char *, char *);
 void		get_xml_first_element(xmlNode *, xmlDoc *, char *, char *, int);
 
-/* news_list.c */
-char		**init_url_list();
-char		**init_selected_url_list();
-char		**get_url_list();
-char		**get_selected_url_list();
-int		load_selected_url_list(char **);
-int		load_url_list(char **);
-void		sort_url_list(char **, int);
-int		save_url_list(char **);
-void		remove_url_from_list(char **, int);
-int		search_in_url_list(char **, const char *);
-gboolean	str_has_title(char *);
-char		*str_without_title(char *);
-
-/* news_rsswin.c */
+/* tickr_feedpicker.c */
+void		highlight_and_go_to_row(GtkTreeView *, GtkTreeSelection *, int);
 void		get_new_url(Resource *);
 
-/* news_prefwin.c */
+/* tickr_prefwin.c */
 int		modify_params(Params *);
 
-/* news_otherwins.c */
+/* tickr_otherwins.c */
 void		open_new_txt_file(Resource *resrc);
 void		help_win();
 void		about_win();
 void		info_win(const char *, const char *, info_type, gboolean);
 void		info_win_wait(const char *, int);
 int		question_win(const char *);
-int		question_win_always_on_top(const char *);
-void		win_with_spinner(spinner_win_mode, const char *);
+int		question_win_at(const char *, int);
+void		win_with_spinner(win_with_spinner_mode, const char *);
+void		win_with_progress_bar(win_with_progress_bar_mode, const char *);
 
-/* news_misc.c */
+/* tickr_misc.c */
 void		import_params();
 void		export_params();
 void		online_help();
-void		warning(const char *, const char*, const char*, const char *, gboolean);
+void		warning(gboolean, int, ...);
 void		dump_font_list();
 
-/* news_hlptxt.c */
+/* tickr_hlptxt.c */
 #if USE_GUI
 const char	**get_help_str0();
 #endif
@@ -613,25 +604,21 @@ const char	**get_help_str1();
 const char	**get_license_str1();
 const char	*get_license_str2();
 
-/* news_ompl.c */
+/* tickr_ompl.c */
 void		import_opml_file();
 char		*pick_opml_file();
 int		parse_opml_xml_file(const char *);
 void		get_opml_selected_element(xmlNode *, const char *, const char *);
 void		export_opml_file();
-char		*create_opml_str_from_url_list(char **);
+char		*create_opml_str_from_feed_list_node(FList *);
 int		save_str_as_opml_file(const char *);
 
-/* news_http.c */
-#ifndef G_OS_WIN32
-int		connect_with_url(int *, char *);
-#else
-int		connect_with_url(SOCKET *, char *);
-#endif
+/* tickr_http.c */
+int		connect_with_url(sockt *, char *);
 int		fetch_resource(const char *, const char *, char *);
 const char	*build_http_request(const char *, const char *, const char *,\
 			const char *);
-int 		get_http_response(int, const char *, const char *, const char *,\
+int 		get_http_response(sockt, const char *, const char *, const char *,\
 			char **, char **, int *);
 int		get_http_status_code(const char *);
 const char	*get_http_header_value(const char *, const char *);
@@ -641,21 +628,11 @@ int		get_http_chunk_size(const char *);
 const char	*get_scheme_from_url(const char*);
 const char	*get_host_from_url(const char*);
 const char	*get_path_from_url(const char*);
-#ifndef G_OS_WIN32
-int		connect_to_host(const char *, const char *);
-int		writable_data_is_available_on_socket(int);
-int		readable_data_is_available_on_socket(int);
-int		send_full(int, const char *);
-char		*recv_full(int, int *, int *);
-#else
-SOCKET		connect_to_host(const char *, const char *);
-int		writable_data_is_available_on_socket(SOCKET);
-int		readable_data_is_available_on_socket(SOCKET);
-int		send_full(SOCKET, const char *);
-char		*recv_full(SOCKET, int *, int *);
-#endif
 
-/* news_connectwin.c */
+/* tickr_socket.c */
+/* proto moved into tickr_socket.h */
+
+/* tickr_connectwin.c */
 void		init_authentication();
 void		init_proxy();
 void		compute_auth_and_proxy_str();
@@ -675,3 +652,7 @@ void		set_use_proxy_auth(gboolean);
 char		*get_proxy_auth_user();
 char		*get_proxy_auth_psw();
 char		*get_proxy_auth_str();
+
+/* tickr_quickfeedpicker.c */
+void		quick_feed_picker(int);
+#endif /* INC_TICKR_H */
