@@ -1,5 +1,5 @@
 /*
- *	TICKR - GTK-based Feed Reader - Copyright (C) Emmanuel Thomas-Maurin 2009-2011
+ *	TICKR - GTK-based Feed Reader - Copyright (C) Emmanuel Thomas-Maurin 2009-2012
  *	<manutm007@gmail.com>
  *
  * 	This program is free software: you can redistribute it and/or modify
@@ -55,11 +55,9 @@ void init_proxy()
 }
 
 #if USE_GUI
-static gint enter_key_pressed_in_entry(GtkWidget *widget, GdkEvent *event, gpointer unused)
+static gint enter_key_pressed_in_entry(GtkWidget *widget)
 {
 	widget = widget;
-	event = event;
-	unused = unused;
 	gtk_dialog_response(GTK_DIALOG(dialog), GTK_RESPONSE_OK);
 	return TRUE;
 }
@@ -89,29 +87,23 @@ static void set_entries_sensitive3(gboolean state)
 	gtk_widget_set_sensitive(entry_proxy_psw, state);
 }
 
-static gint check_but1_toggled(GtkWidget *check_button, GdkEvent *event, gpointer unused)
+static gint check_but1_toggled(GtkWidget *check_button)
 {
-	event = event;
-	unused = unused;
 	auth->use_authentication = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check_button));
 	set_entries_sensitive1(auth->use_authentication);
 	return TRUE;
 }
 
-static gint check_but2_toggled(GtkWidget *check_button, GdkEvent *event, gpointer unused)
+static gint check_but2_toggled(GtkWidget *check_button)
 {
-	event = event;
-	unused = unused;
 	proxy->use_proxy = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check_button));
 	set_entries_sensitive2(proxy->use_proxy);
 	set_entries_sensitive3(proxy->use_proxy && proxy->use_proxy_authentication);
 	return TRUE;
 }
 
-static gint check_but3_toggled(GtkWidget *check_button, GdkEvent *event, gpointer unused)
+static gint check_but3_toggled(GtkWidget *check_button)
 {
-	event = event;
-	unused = unused;
 	proxy->use_proxy_authentication = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check_button));
 	set_entries_sensitive3(proxy->use_proxy && proxy->use_proxy_authentication);
 	return TRUE;
@@ -174,7 +166,7 @@ gint connection_settings(connection_settings_page page)
 			GTK_STOCK_OK, GTK_RESPONSE_OK,
 			NULL);
 
-	set_news_icon_to_dialog(GTK_WINDOW(dialog));
+	set_tickr_icon_to_dialog(GTK_WINDOW(dialog));
 	gtk_window_set_position(GTK_WINDOW(dialog), GTK_WIN_POS_CENTER);
 	/*
 	 * fill structs from params
