@@ -1,5 +1,5 @@
 /*
- *	TICKR - GTK-based Feed Reader - Copyright (C) Emmanuel Thomas-Maurin 2009-2011
+ *	TICKR - GTK-based Feed Reader - Copyright (C) Emmanuel Thomas-Maurin 2009-2012
  *	<manutm007@gmail.com>
  *
  * 	This program is free software: you can redistribute it and/or modify
@@ -26,14 +26,14 @@ static const char *help_str0[] = {
 
 "- To open a link in your Browser, left-click on the text.\n\n",
 
-"Basically, you will use 'File > Open RSS Feed' to choose a feed from a list\n",
+"Basically, you will use 'File > Open Feed (RSS|Atom)' to choose a feed from a list\n",
 "or to subscribe to a new one and 'Edit > Preferences' to tweak the ticker\n",
 "appearance as well as other settings.\n\n",
 
 "***ONLY*** in case you're using the ticker inside a ***decorated*** window,\n",
 "you can use keyboard shortcuts:\n\n",
 
-"- <Ctrl>R to open the RSS Feed Picker window (to choose a feed or to\n",
+"- <Ctrl>R to open the Feed Picker window (to choose a feed or to\n",
 "  subscribe to a new one.)\n\n",
 
 "- <Ctrl>T to open a text file.\n\n",
@@ -76,11 +76,11 @@ NULL};
 #endif
 
 static const char *help_str1[] = {
-	APP_NAME"-"APP_VERSION_NUMBER" - GTK-based highly graphically-customizable RSS Ticker\n",
-	"Copyright (C) 2009-2011 Emmanuel Thomas-Maurin <manutm007@gmail.com>\n\n",
-	APP_NAME" is a GTK-based RSS Reader that displays feeds as a smooth scrolling line\n",
-	"on your Desktop, as known from TV stations. Open feed links in your favourite\n",
-	"Browser. Graphics are highly customizable.\n\n",
+	APP_NAME"-"APP_VERSION_NUMBER" - GTK-based highly graphically-customizable Feed Ticker\n",
+	"Copyright (C) 2009-2012 Emmanuel Thomas-Maurin <manutm007@gmail.com>\n\n",
+	APP_NAME" is a GTK-based RSS/Atom Reader that displays feeds as a smooth\n"
+	"scrolling line on your Desktop, as known from TV stations. Open feed\n"
+	"links in your favourite Browser. Graphics are highly customizable.\n\n"
 	"Usage:\n",
 	"        "APP_CMD" [-help / -version / -license / -instance-id=n / -dumpfontlist]\n",
 	"              [options (-name[=value])...] [resource (file name or URL)]\n\n",
@@ -123,7 +123,6 @@ static const char *help_str1[] = {
 	"        rssdescription=[y/n]           Show or hide description\n\n",
 	"        rssdescriptiondelimiter='str'  String to be appended after description\n\n",
 	"        nitemsperfeed=n                Read N items max per feed\n\n",
-/*	"        readinloop=[y/n]               Read in loop / read only once\n\n",*/
 	"        rmtags=[y/n]                   Strip html tags\n\n",
 	"        uppercasetext=[y/n]            Set all text to upper case\n\n",
 	"        homefeed='str'                 Set URL as 'homefeed' = homepage\n",
@@ -167,10 +166,10 @@ static const char *help_str1[] = {
 	APP_NAME" parses command line arguments and looks for option(s) then for one\n",
 	"resource, the rest of the line is ignored. It reads too configuration file\n",
 #ifndef G_OS_WIN32
-	"'"APP_CMD"-conf' located in /home/<user_name>/"NEWS_DIR_NAME"/ if it exists (or\n",
+	"'"APP_CMD"-conf' located in /home/<user_name>/"TICKR_DIR_NAME"/ if it exists (or\n",
 	"'"APP_CMD"-conf<n>' if an instance id has been set to n.)\n\n",
 #else
-	"'"APP_CMD"-conf' located in <Application Data directory>"NEWS_DIR_NAME"/ if it exists (or\n",
+	"'"APP_CMD"-conf' located in <Application Data directory>"TICKR_DIR_NAME"/ if it exists (or\n",
 	"'"APP_CMD"-conf<n>' if an instance id has been set to n.)\n\n",
 #endif
 	"Command line options override configuration file ones which override default\n",
@@ -180,7 +179,7 @@ static const char *help_str1[] = {
 	NULL};
 
 static const char *license_str1[] = {
-	APP_NAME" version "APP_VERSION_NUMBER" - Copyright (C) Emmanuel Thomas-Maurin 2009-2011\n\n",
+	APP_NAME" version "APP_VERSION_NUMBER" - Copyright (C) Emmanuel Thomas-Maurin 2009-2012\n\n",
 	APP_NAME" is free software: you can redistribute it and/or modify\n",
 	"it under the terms of the GNU General Public License as published by\n",
 	"the Free Software Foundation, either version 3 of the License, or\n",
