@@ -1,5 +1,5 @@
 /*
- *	TICKR - GTK-based Feed Reader - Copyright (C) Emmanuel Thomas-Maurin 2009-2011
+ *	TICKR - GTK-based Feed Reader - Copyright (C) Emmanuel Thomas-Maurin 2009-2012
  *	<manutm007@gmail.com>
  *
  * 	This program is free software: you can redistribute it and/or modify
@@ -20,27 +20,17 @@
 
 #ifdef G_OS_WIN32
 extern FILE	*stdout_fp, *stderr_fp;
-static gchar	*error_msg;
-
 #endif
 
 /* are these values ok? */
 #define HTTP_REQUEST_MAXLEN		(8 * 1024 - 1)
 #define HTTP_HEADER_FIELD_MAXLEN	(2 * 1024 - 1)
-#define RECV_CHUNK_LEN			(16 * 1024 - 1)
-#define CONNECT_TIMEOUT			5
-#define SEND_RECV_TIMEOUT		1
 #define MAX_HTTP_REDIRECT		8
 #define DEFAULT_HTTP_PORT_STR		"80"
 #define DEFAULT_HTTPS_PORT_STR		"443"
 #define	PORT_STR_MAXLEN			PROXY_PORT_MAXLEN
 #define TAB				'\x09'
 
-#ifndef G_OS_WIN32
-# define CLOSE_SOCK	close(sock)
-#else
-# define CLOSE_SOCK	closesocket(sock)
-#endif
 /* S_MOD -> true in multiple selection mode / false otherwise */
 #define S_MOD		(get_ticker_env()->selection_mode == MULTIPLE)
 
@@ -106,15 +96,10 @@ static int format_quick_check(char *response, int *shift)
 }
 
 /* get host from url but if connecting through proxy */
-#ifndef G_OS_WIN32
-int connect_with_url(int *sock, char *url)
-#else
-int connect_with_url(SOCKET *sock, char *url)
-#endif
+int connect_with_url(sockt *sock, char *url)
 {
 	char		host[FILE_NAME_MAXLEN + 1];
 	char		port_num[PORT_STR_MAXLEN + 1];
-	char		tmp[256];
 	static int	connect_fail_count = 0;
 
 	if (!get_use_proxy()) {
@@ -124,17 +109,16 @@ int connect_with_url(SOCKET *sock, char *url)
 		/* https is not supported so far */
 		else if (strcmp(get_scheme_from_url(url), "https") == 0) {
 			/*str_n_cpy(port_num, DEFAULT_HTTPS_PORT_STR, PORT_STR_MAXLEN);*/
-			warning(url, ":\nHTTPS protocol not currently supported",
-				"", "", S_MOD);
+			warning(S_MOD, 2, url, ":\nHTTPS protocol not currently supported");
 			return HTTP_UNSUPPORTED_SCHEME;
 		} else if (strcmp(get_scheme_from_url(url), "file") == 0)
 			;/* do nothing here */
 		else if (get_scheme_from_url(url)[0] == '\0') {
-			warning("No scheme found in URL:", url, "", "", S_MOD);
+			warning(S_MOD, 2, "No scheme found in URL: ", url);
 			return HTTP_UNSUPPORTED_SCHEME;
 		} else {
-			warning("Unsupported or unknown scheme in URL:",
-				get_scheme_from_url(url), "", "", S_MOD);
+			warning(S_MOD, 2, "Unsupported or unknown scheme in URL: ",
+				get_scheme_from_url(url));
 			return HTTP_UNSUPPORTED_SCHEME;
 		}
 	} else {
@@ -142,22 +126,17 @@ int connect_with_url(SOCKET *sock, char *url)
 		str_n_cpy(host, get_proxy_host(), FILE_NAME_MAXLEN);
 		str_n_cpy(port_num, get_proxy_port(), PORT_STR_MAXLEN);
 	}
-#ifndef G_OS_WIN32
-	if ((*sock = connect_to_host(host, port_num)) > -1) {
-
-#else
-	if ((*sock = connect_to_host(host, port_num)) != INVALID_SOCKET) {
-#endif
+	if ((*sock = connect_to_host(host, port_num)) != SOCK_CREATE_ERROR) {
 		connect_fail_count = 0;
 		return OK;
 	} else {
 		if (get_use_proxy()) {
-			snprintf(tmp, 256, "%s:%s", get_proxy_host(), get_proxy_port());
-			warning("Can't connect to proxy:", tmp, "", "", FALSE);
+			warning(FALSE, 4, "Can't connect to proxy: ",
+				get_proxy_host(),":", get_proxy_port());
 			current_feed();
 			connection_settings(PROXY_PAGE);
 		} else if (get_ticker_env()->selection_mode == SINGLE)
-			warning("Can't connect to host:", host, "", "", FALSE);
+			warning(FALSE, 2, "Can't connect to host: ", host);
 		else
 			fprintf(STD_ERR, "Can't connect to host: %s\n", host);
 		if (++connect_fail_count >= CONNECT_FAIL_MAX) {
@@ -168,14 +147,15 @@ int connect_with_url(SOCKET *sock, char *url)
 	}
 }
 
+/* ***********************************
+ *   TODO: DOCUMENT BETTER THIS FUNC
+ * ***********************************/
 /* we replace resrc->id with modified url and file_name = downloaded resource
  * maxlen of file_name, url, new_url = FILE_NAME_MAXLEN */
 int fetch_resource(const char *resrc_id, const char *file_name, char *url)
 {
-#ifndef G_OS_WIN32
-	int	sock;
-#else
-	SOCKET	sock;
+	sockt	sock;
+#ifdef G_OS_WIN32
 	gchar	*win32_filename;
 #endif
 	int	status, recv_status;
@@ -211,10 +191,10 @@ int fetch_resource(const char *resrc_id, const char *file_name, char *url)
 				} else {
 					g_free(response);
 					if (error != NULL) {
-						warning(error->message, "", "", "", FALSE);
+						warning(FALSE, 1, error->message);
 						g_error_free(error);
 					} else
-						warning("Can't create file:", file_name, "", "", FALSE);
+						warning(FALSE, 2, "Can't create file: ", file_name);
 					return CREATE_FILE_ERROR;
 				}
 			} else {
@@ -226,10 +206,10 @@ int fetch_resource(const char *resrc_id, const char *file_name, char *url)
 			g_free(win32_filename);
 #endif
 			if (error != NULL) {
-				warning(error->message, "", "", "", S_MOD);
+				warning(S_MOD, 1, error->message);
 				g_error_free(error);
 			} else
-				warning("Can't open file:", url + i, "", "", S_MOD);
+				warning(S_MOD, 2, "Can't open file: ", url + i);
 			return OPEN_FILE_ERROR;
 		}
 	} else
@@ -239,7 +219,7 @@ int fetch_resource(const char *resrc_id, const char *file_name, char *url)
 		if ((status = get_http_response(sock, "GET", "", url, &new_url,
 				&response, &recv_status)) == SEND_ERROR || status == RECV_ERROR) {
 			if (recv_status == CONNECTION_CLOSED_BY_SERVER || recv_status == SOCK_SHOULD_BE_CLOSED)
-				CLOSE_SOCK;
+				CLOSE_SOCK(sock);
 			return i;
 		}
 	} else
@@ -253,11 +233,11 @@ int fetch_resource(const char *resrc_id, const char *file_name, char *url)
 			continue;
 		} else if (status == HTTP_SWITCH_PROTO) {
 			if (strcmp(get_http_header_value("Upgrade", response), "HTTP") == 0)
-				warning(url, ":\nSwitching to HTTP protocol requested for this connection",
-					"-", "Request currently not supported", S_MOD);
+				warning(S_MOD, 2, url, ":\nSwitching to HTTP protocol requested for this connection"
+					" - Request currently not supported");
 			else if (strcmp(get_http_header_value("Upgrade", response), "HTTPS") == 0)
-				warning(url, ":\nSwitching to HTTPS protocol requested for this connection",
-					"-", "Request currently not supported", S_MOD);
+				warning(S_MOD, 2, url, ":\nSwitching to HTTPS protocol requested for this connection"
+					" - Request currently not supported");
 			return status;
 		} else if (status == OK) {
 			if (strcmp(get_http_header_value("Transfer-Encoding", response), "chunked") == 0) {
@@ -284,14 +264,13 @@ int fetch_resource(const char *resrc_id, const char *file_name, char *url)
 				fprintf(fp, "%s", response + i);
 				fclose(fp);
 				free2(response);
-				CLOSE_SOCK;
+				CLOSE_SOCK(sock);
 				return OK;
 			} else {
-				warning("Can't create file:", file_name,
-					"", "", FALSE);
+				warning(FALSE, 2, "Can't create file: ", file_name);
 				fclose(fp);
 				free2(response);
-				CLOSE_SOCK;
+				CLOSE_SOCK(sock);
 				return CREATE_FILE_ERROR;
 			}
 		} else if (status == HTTP_MOVED) {
@@ -301,10 +280,10 @@ int fetch_resource(const char *resrc_id, const char *file_name, char *url)
 				if (strcmp(get_http_header_value("Connection", response), "close") == 0 ||\
 						strcmp(get_scheme_from_url(url), "https") == 0) {
 					free2(response);
-					CLOSE_SOCK;
+					CLOSE_SOCK(sock);
 					if (strcmp(get_scheme_from_url(url), "https") == 0) {
-						warning(resrc_id, ":\nHTTPS protocol requested for this connection",
-							"(following HTTP moved) -", "Not currently supported", S_MOD);
+						warning(S_MOD, 2, resrc_id, ":\nHTTPS protocol requested for this connection"
+							" (following HTTP moved) - Not currently supported");
 						return HTTP_ERROR;	/* ???? */
 					}
 					if ((j = connect_with_url(&sock, url)) != OK)
@@ -317,24 +296,24 @@ int fetch_resource(const char *resrc_id, const char *file_name, char *url)
 			if (status != HTTP_MOVED && i <= MAX_HTTP_REDIRECT)
 				continue;
 			else {
-				warning(resrc_id, ":\nToo many HTTP redirects", "", "", S_MOD);
+				warning(S_MOD, 2, resrc_id, ":\nToo many HTTP redirects");
 				free2(response);
-				CLOSE_SOCK;
+				CLOSE_SOCK(sock);
 				return HTTP_TOO_MANY_REDIRECTS;
 			}
 		} else if (status == HTTP_USE_PROXY) {
-			warning("Resource: ", url, "\nmust be accessed through proxy.\nProxy host:",
-				new_url, FALSE);
+			warning(FALSE, 4, "Resource: ", url, "\nmust be accessed through proxy.\nProxy host: ",
+				new_url);
 			str_n_cpy(get_proxy_host(), new_url, PROXY_HOST_MAXLEN);
 			free2(response);
-			CLOSE_SOCK;
+			CLOSE_SOCK(sock);
 			connection_settings(PROXY_PAGE);
 			current_feed();
 			return status;
 		} else if (status == HTTP_PROXY_AUTH_REQUIRED) {
 			/* proxy authentication */
 			free2(response);
-			CLOSE_SOCK;
+			CLOSE_SOCK(sock);
 			if (get_use_proxy_auth()) {
 				if ((i = connect_with_url(&sock, url)) != OK)
 					return i;
@@ -343,10 +322,9 @@ int fetch_resource(const char *resrc_id, const char *file_name, char *url)
 					get_proxy_auth_str());
 				if ((status = get_http_response(sock, "GET", header_field, url, &new_url,
 						&response, &recv_status)) == HTTP_PROXY_AUTH_REQUIRED) {
-					warning("Proxy authentication failed for:",
-						get_proxy_host(), "", "", FALSE);
+					warning(FALSE, 2, "Proxy authentication failed for: ", get_proxy_host());
 					free2(response);
-					CLOSE_SOCK;
+					CLOSE_SOCK(sock);
 					if (connection_settings(PROXY_PAGE) == GTK_RESPONSE_OK) {
 						if ((i = connect_with_url(&sock, url)) != OK)
 							return i;
@@ -357,8 +335,7 @@ int fetch_resource(const char *resrc_id, const char *file_name, char *url)
 				}
 				continue;
 			} else {
-				warning("Proxy authentication required for:",
-					get_proxy_host(), "", "", FALSE);
+				warning(FALSE, 2, "Proxy authentication required for: ", get_proxy_host());
 				if (connection_settings(PROXY_PAGE) == GTK_RESPONSE_OK &&\
 					get_use_proxy_auth()) {
 					if ((i = connect_with_url(&sock, url)) != OK)
@@ -375,7 +352,7 @@ int fetch_resource(const char *resrc_id, const char *file_name, char *url)
 		} else if (status == HTTP_UNAUTHORIZED) {
 			/* http authentication - only basic so far */
 			free2(response);
-			CLOSE_SOCK;
+			CLOSE_SOCK(sock);
 			if (get_use_authentication()) {
 				if ((i = connect_with_url(&sock, url)) != OK)
 					return i;
@@ -384,9 +361,9 @@ int fetch_resource(const char *resrc_id, const char *file_name, char *url)
 					get_http_auth_str());
 				if ((status = get_http_response(sock, "GET", header_field,
 						url, &new_url, &response, &recv_status)) == HTTP_UNAUTHORIZED) {
-					warning("HTTP authentication failed for:", url, "", "", FALSE);
+					warning(FALSE, 2, "HTTP authentication failed for: ", url);
 					free2(response);
-					CLOSE_SOCK;
+					CLOSE_SOCK(sock);
 					if (connection_settings(AUTH_PAGE) == GTK_RESPONSE_OK) {
 						if ((i = connect_with_url(&sock, url)) != OK)
 							return i;
@@ -397,8 +374,7 @@ int fetch_resource(const char *resrc_id, const char *file_name, char *url)
 				}
 				continue;
 			} else {
-				warning("HTTP authentication required for:",
-					url, "", "", FALSE);
+				warning(FALSE, 2, "HTTP authentication required for: ", url);
 				if (connection_settings(AUTH_PAGE) == GTK_RESPONSE_OK &&\
 					get_use_authentication()) {
 					if ((i = connect_with_url(&sock, url)) != OK)
@@ -413,38 +389,36 @@ int fetch_resource(const char *resrc_id, const char *file_name, char *url)
 					return HTTP_NO_AUTH_CREDENTIALS;
 			}
 		} else if (status == HTTP_BAD_REQUEST) {
-			warning(url, ":\nBad Request", "", "", S_MOD);
+			warning(S_MOD, 2, url, ":\nBad Request");
 			free2(response);
-			CLOSE_SOCK;
+			CLOSE_SOCK(sock);
 			return status;
 		} else if (status == HTTP_FORBIDDEN) {
-			warning(url, ":\nForbidden", "", "", S_MOD);
+			warning(S_MOD, 2, url, ":\nForbidden");
 			free2(response);
-			CLOSE_SOCK;
+			CLOSE_SOCK(sock);
 			return status;
 		} else if (status == HTTP_NOT_FOUND) {
-			warning(url, ":\nNot found", "", "", S_MOD);
+			warning(S_MOD, 2, url, ":\nNot found");
 			free2(response);
-			CLOSE_SOCK;
+			CLOSE_SOCK(sock);
 			return status;
 		} else if (status == HTTP_INT_SERVER_ERROR) {
-			warning(url, ":\nInternal server error", "", "",
-				S_MOD);
+			warning(S_MOD, 2, url, ":\nInternal server error");
 			free2(response);
-			CLOSE_SOCK;
+			CLOSE_SOCK(sock);
 			return status;
 		} else if (status == HTTP_NO_STATUS_CODE) {
-			warning(url, ":\nNo HTTP status code returned",
-				"", "", S_MOD);
+			warning(S_MOD, 2, url, ":\nNo HTTP status code returned");
 			free2(response);
-			CLOSE_SOCK;
+			CLOSE_SOCK(sock);
 			return status;
 		} else {
-			warning(url, ":\nHTTP response status code: ",
-				itoa2(status - 1000), "", S_MOD);
+			warning(S_MOD, 3, url, ":\nHTTP response status code: ",
+				itoa2(status - 1000));
 			if (response != NULL)
 				free2(response);
-			CLOSE_SOCK;
+			CLOSE_SOCK(sock);
 			return HTTP_ERROR;
 		}
 	}
@@ -469,7 +443,7 @@ const char *build_http_request(const char *method, const char *path,\
  * rq_str may contain header field(s) separated and ended by "\r\n"
  * must 'free2' response afterwards
  */
-int get_http_response(int sock, const char *rq_method, const char *rq_str,
+int get_http_response(sockt sock, const char *rq_method, const char *rq_str,
 	const char *rq_url, char **new_rq_url, char **response, int *recv_status)
 {
 	char		*str;
@@ -704,413 +678,3 @@ const char *get_path_from_url(const char* url)
 		str[0] = '\0';
 	return (const char *)str;
 }
-
-#ifndef G_OS_WIN32
-/* can use IPv4 or IPv6 */
-static void *get_in_addr(struct sockaddr *s_a)
-{
-	if (s_a->sa_family == AF_INET)
-		return &(((struct sockaddr_in *)s_a)->sin_addr);
-	else
-		return &(((struct sockaddr_in6 *)s_a)->sin6_addr);
-}
-#endif
-
-/* return socket fd (> 0) / -1 if error */
-#ifndef G_OS_WIN32
-int connect_to_host(const char *host, const char *portnum_str)
-#else
-SOCKET connect_to_host(const char *host, const char *portnum_str)
-#endif
-{
-#ifndef G_OS_WIN32
-	int			sock;
-	char			ipa_str[INET6_ADDRSTRLEN];
-#else
-	SOCKET			sock;
-	u_long			i_mode = 1;	/* != 0 to enable non-blocking mode */
-#endif
-	struct addrinfo		hints, *server_info, *ptr;
-	fd_set			readset, writeset;
-	struct timeval		timeout;
-	int			s_opt_value;
-	socklen_t		s_opt_len = sizeof(int);
-	int			i;
-
-	/* addrinfo stuff */
-	memset(&hints, 0, sizeof(hints));
-	hints.ai_family = AF_UNSPEC;
-	hints.ai_socktype = SOCK_STREAM;
-/*#ifdef VERBOSE_OUTPUT
-	fprintf(STD_OUT, "Resolving %s ... ", host);
-#endif*/
-	if ((i = getaddrinfo(host, portnum_str, &hints, &server_info)) != 0) {
-		if (get_use_proxy() || get_ticker_env()->selection_mode == SINGLE) {
-#ifndef G_OS_WIN32
-			warning("getaddrinfo() error:", host, ":", gai_strerror(i), FALSE);
-#else
-			error_msg = g_win32_error_message(WSAGetLastError());
-			warning("getaddrinfo() error:", host, ":", error_msg, FALSE);
-			g_free(error_msg);
-#endif
-		} else {
-#ifndef G_OS_WIN32
-			fprintf(STD_ERR, "getaddrinfo() error: %s: %s\n", host, gai_strerror(i));
-#else
-			error_msg = g_win32_error_message(WSAGetLastError());
-			fprintf(STD_ERR, "getaddrinfo() error: %s: %s\n", host, error_msg);
-			g_free(error_msg);
-#endif
-		}
-		return -1;
-	}
-/*#ifdef VERBOSE_OUTPUT
-	fprintf(STD_OUT, "Done\n");
-#endif*/
-	/* we get a list */
-	for (ptr = server_info; ptr != NULL; ptr = ptr->ai_next) {
-		/* create socket */
-#ifndef G_OS_WIN32
-		if ((sock = socket(ptr->ai_family, ptr->ai_socktype, ptr->ai_protocol)) == -1) {
-			fprintf(STD_ERR, "Error: %s\n", strerror(errno));
-#else
-		if ((sock = socket(ptr->ai_family, ptr->ai_socktype, ptr->ai_protocol)) == INVALID_SOCKET) {
-			error_msg = g_win32_error_message(WSAGetLastError());
-			fprintf(STD_ERR, "Error: %s\n", error_msg);
-			g_free(error_msg);
-#endif
-			continue;
-		}
-		/* set socket in non-blocking mode */
-#ifndef G_OS_WIN32
-		if ((i = fcntl(sock, F_GETFL, 0)) == -1) {
-			fprintf(STD_ERR, "fcntl() error: %s\n", strerror(errno));
-			close(sock);
-			break;
-		} else if (fcntl(sock, F_SETFL, i | O_NONBLOCK) == -1) {
-			fprintf(STD_ERR, "fcntl() error: %s\n", strerror(errno));
-			close(sock);
-			break;
-		}
-#else
-		if (ioctlsocket(sock, FIONBIO, &i_mode) != NO_ERROR) {
-			error_msg = g_win32_error_message(WSAGetLastError());
-			fprintf(STD_ERR, "ioctlsocket() error %s\n", error_msg);
-			g_free(error_msg);
-			closesocket(sock);
-			break;
-		}
-#endif
-		/* get IP addr from server_info */
-#ifdef VERBOSE_OUTPUT
-#ifndef G_OS_WIN32
-		inet_ntop(ptr->ai_family, get_in_addr((struct sockaddr *)ptr->ai_addr),
-			ipa_str, sizeof(ipa_str));
-		fprintf(STD_OUT, "Connecting to %s (%s) ... ", ipa_str, host);
-#else
-		/* available only on vista and above but we don't really need that (do we?) so disabled
-		InetNtop(ptr->ai_family, get_in_addr((struct sockaddr *)ptr->ai_addr), s, sizeof(s));*/
-		fprintf(STD_OUT, "Connecting to %s ... ", host);
-#endif
-		fflush(stdout);
-#endif
-		/* connect */
-#ifndef G_OS_WIN32
-		if ((i = connect(sock, ptr->ai_addr, ptr->ai_addrlen)) == -1 && errno == EINPROGRESS) {
-#else
-		if ((i = connect(sock, ptr->ai_addr, ptr->ai_addrlen)) == SOCKET_ERROR &&\
-				WSAGetLastError() == WSAEWOULDBLOCK) {
-#endif
-			/* as socket is in non-blocking mode, we must use select() */
-			FD_ZERO(&readset);
-			FD_ZERO(&writeset);
-			FD_SET(sock, &readset);
-			FD_SET(sock, &writeset);
-			timeout.tv_sec = CONNECT_TIMEOUT;
-			timeout.tv_usec = 0;
-#ifndef G_OS_WIN32
-			if ((i = select(sock + 1, &readset, &writeset, NULL, &timeout)) == -1) {
-				fprintf(STD_ERR, "select() error: %s\n", strerror(errno));
-#else
-			if ((i = select(sock + 1, &readset, &writeset, NULL, &timeout)) == SOCKET_ERROR) {
-				error_msg = g_win32_error_message(WSAGetLastError());
-				fprintf(STD_ERR, "select() error: %s\n", error_msg);
-				g_free(error_msg);
-
-#endif
-			} else if (i == 0) {
-				fprintf(STD_ERR, "Timed out\n");
-			} else if (FD_ISSET(sock, &readset) || FD_ISSET(sock, &writeset)) {
-#ifndef G_OS_WIN32
-				if (getsockopt(sock, SOL_SOCKET, SO_ERROR,
-						(void *)(&s_opt_value), &s_opt_len) == -1) {
-					fprintf(STD_ERR, "getsockopt() error: %s\n", strerror(errno));
-#else
-				if (getsockopt(sock, SOL_SOCKET, SO_ERROR,
-						(void *)(&s_opt_value), &s_opt_len) == SOCKET_ERROR) {
-					error_msg = g_win32_error_message(WSAGetLastError());
-					fprintf(STD_ERR, "getsockopt() error: %s\n", error_msg);
-					g_free(error_msg);
-#endif
-				} else if (s_opt_value == 0) {
-#ifdef VERBOSE_OUTPUT
-					fprintf(STD_OUT, "OK\n");
-#endif
-					freeaddrinfo(server_info);
-					return sock;
-				}
-#ifndef G_OS_WIN32
-				fprintf(STD_ERR, "getsockopt(): %s\n", strerror(s_opt_value));
-#else
-				error_msg = g_win32_error_message(s_opt_value);
-				fprintf(STD_ERR, "getsockopt(): %s\n", error_msg);
-				g_free(error_msg);
-#endif
-				CLOSE_SOCK;
-				break;
-			}
-			CLOSE_SOCK;
-			break;
-		} else if (i == 0) {
-#ifdef VERBOSE_OUTPUT
-			fprintf(STD_OUT, "OK\n");
-#endif
-			freeaddrinfo(server_info);
-			return sock;
-		} else {
-
-#ifndef G_OS_WIN32
-			fprintf(STD_ERR, "connect() error: %s\n", strerror(errno));
-#else
-			error_msg = g_win32_error_message(WSAGetLastError());
-			fprintf(STD_ERR, "connect() error: %s\n", error_msg);
-			g_free(error_msg);
-#endif
-			CLOSE_SOCK;
-			/*redundant
-			continue;*/
-		}
-	}
-	freeaddrinfo(server_info);
-	return -1;
-}
-
-#ifndef G_OS_WIN32
-int writable_data_is_available_on_socket(int sock)
-#else
-int writable_data_is_available_on_socket(SOCKET sock)
-#endif
-{
-	fd_set		writeset;
-	struct timeval	timeout;
-	int		i;
-
-	FD_ZERO(&writeset);
-	FD_SET(sock, &writeset);
-	timeout.tv_sec = SEND_RECV_TIMEOUT;
-	timeout.tv_usec = 0;
-#ifndef G_OS_WIN32
-	if ((i = select(sock + 1, NULL, &writeset, NULL, &timeout)) == -1) {
-		fprintf(STD_ERR, "select() error: %s\n", strerror(errno));
-#else
-	if ((i = select(sock + 1, NULL, &writeset, NULL, &timeout)) == SOCKET_ERROR) {
-		error_msg = g_win32_error_message(WSAGetLastError());
-		fprintf(STD_ERR, "select() error: %s\n", error_msg);
-		g_free(error_msg);
-#endif
-		return SELECT_ERROR;
-	} else if (i == 0) {
-		return SELECT_TIMED_OUT;
-	} else {
-		if (FD_ISSET(sock, &writeset))
-			return SELECT_TRUE;
-		else
-			return SELECT_FALSE;
-	}
-}
-
-#ifndef G_OS_WIN32
-int readable_data_is_available_on_socket(int sock)
-#else
-int readable_data_is_available_on_socket(SOCKET sock)
-#endif
-{
-	fd_set		readset;
-	struct timeval	timeout;
-	int		i;
-
-	FD_ZERO(&readset);
-	FD_SET(sock, &readset);
-	timeout.tv_sec = SEND_RECV_TIMEOUT;
-	timeout.tv_usec = 0;
-#ifndef G_OS_WIN32
-	if ((i = select(sock + 1, &readset, NULL, NULL, &timeout)) == -1) {
-		fprintf(STD_ERR, "select() error: %s\n", strerror(errno));
-#else
-	if ((i = select(sock + 1, &readset, NULL, NULL, &timeout)) == SOCKET_ERROR) {
-		error_msg = g_win32_error_message(WSAGetLastError());
-		fprintf(STD_ERR, "select() error: %s\n", error_msg);
-		g_free(error_msg);
-#endif
-		return SELECT_ERROR;
-	} else if (i == 0) {
-		return SELECT_TIMED_OUT;
-	} else {
-		if (FD_ISSET(sock, &readset))
-			return SELECT_TRUE;
-		else
-			return SELECT_FALSE;
-	}
-}
-
-/* return n bytes sent or -1 if error (connection closed by server or ?) */
-#ifndef G_OS_WIN32
-int send_full(int sock, const char *str)
-{
-	int	len = strlen(str), i, j = 0;
-
-	while (writable_data_is_available_on_socket(sock) == SELECT_TRUE) {
-		if ((i = send(sock, str + j, len, 0)) > 0) {
-			j += i;
-			len -= i;
-			if (len == 0)
-				break;
-		} else if (i == 0) {
-			/* something to do? */
-		} else if (i == -1) {
-			j = -1;
-			if (errno == EPIPE) {
-#ifdef VERBOSE_OUTPUT
-				fprintf(STD_ERR, "Connection closed by server\n");
-#endif
-			} else
-				fprintf(STD_ERR, "send() error: %s\n", strerror(errno));
-			break;
-		}
-	}
-	return j;
-}
-#else
-int send_full(SOCKET sock, const char *str)
-{
-	int	len = strlen(str), i, j = 0;
-
-	while (writable_data_is_available_on_socket(sock) == SELECT_TRUE) {
-		if ((i = send(sock, str + j, len, 0)) != SOCKET_ERROR) {
-			if (i > 0) {
-				j += i;
-				len -= i;
-				if (len == 0)
-					break;
-			} else {
-				/* something to do? */
-			}
-		} else {
-			j = -1;
-			if ((i = WSAGetLastError()) == WSAECONNRESET || i == WSAECONNABORTED ||\
-					i == WSAESHUTDOWN) {
-#ifdef VERBOSE_OUTPUT
-				fprintf(STD_ERR, "Connection closed by server\n");
-#endif
-			} else {
-				error_msg = g_win32_error_message(i);
-				fprintf(STD_ERR, "send() error: %s\n", error_msg);
-				g_free(error_msg);
-			}
-			break;
-		}
-	}
-	return j;
-}
-#endif
-
-/*
- * return response = recv_full(socket, &bytes_received, &status) or NULL if error
- * -> status = ok, connection_closed_by_server or recv_error
- * -> allocate memory for response (must be freed afterwards with free2() if != NULL)
- */
-#ifndef G_OS_WIN32
-char *recv_full(int sock, int *bytes_received, int *status)
-{
-	char	*response, *full_response;
-	int	i;
-
-	*bytes_received = 0;
-	*status = RECV_ERROR;
-	response = malloc2(RECV_CHUNK_LEN + 1);
-	response[0] = '\0';
-	full_response = l_str_new(response);
-	while (readable_data_is_available_on_socket(sock) == SELECT_TRUE) {
-		if ((i = recv(sock, response, RECV_CHUNK_LEN, 0)) > 0) {
-			response[MIN(i, RECV_CHUNK_LEN)] = '\0';
-			full_response = l_str_cat(full_response, response);
-			*bytes_received += i;
-			*status = OK;
-		} else if (i == 0) {
-			*status = CONNECTION_CLOSED_BY_SERVER;
-#ifdef VERBOSE_OUTPUT
-			fprintf(STD_ERR, "Connection closed by server\n");
-#endif
-			break;
-		} else if (i == -1) {
-			*status = RECV_ERROR;
-			l_str_free(full_response);
-			full_response = NULL;
-#ifdef VERBOSE_OUTPUT
-			fprintf(STD_ERR, "recv() error: %s\n", strerror(errno));
-#endif
-			break;
-		}
-	}
-	free2(response);
-	return full_response;
-}
-#else
-char *recv_full(SOCKET sock, int *bytes_received, int *status)
-{
-	char	*response, *full_response;
-	int	i;
-
-	*bytes_received = 0;
-	*status = RECV_ERROR;
-	response = malloc2(RECV_CHUNK_LEN + 1);
-	response[0] = '\0';
-	full_response = l_str_new(response);
-	while (readable_data_is_available_on_socket(sock) == SELECT_TRUE) {
-		if ((i = recv(sock, response, RECV_CHUNK_LEN, 0)) != SOCKET_ERROR) {
-			if (i > 0) {
-				response[MIN(i, RECV_CHUNK_LEN)] = '\0';
-				full_response = l_str_cat(full_response, response);
-				*bytes_received += i;
-				*status = OK;
-			} else {
-				*status = CONNECTION_CLOSED_BY_SERVER;
-#ifdef VERBOSE_OUTPUT
-				fprintf(STD_ERR, "Connection closed by server\n");
-#endif
-				break;
-			}
-		} else {
-			if ((i = WSAGetLastError()) == WSAECONNRESET || i == WSAECONNABORTED ||\
-					i == WSAESHUTDOWN) {
-				*status = SOCK_SHOULD_BE_CLOSED;
-#ifdef VERBOSE_OUTPUT
-				fprintf(STD_ERR, "Connection closed by server\n");
-#endif
-			} else {
-				*status = RECV_ERROR;
-				l_str_free(full_response);
-				full_response = NULL;
-#ifdef VERBOSE_OUTPUT
-				error_msg = g_win32_error_message(i);
-				fprintf(STD_ERR, "recv() error: %s\n", error_msg);
-				g_free(error_msg);
-#endif
-			}
-			break;
-		}
-	}
-	free2(response);
-	return full_response;
-}
-#endif
