@@ -1,5 +1,5 @@
 /*
- *	TICKR - GTK-based Feed Reader - Copyright (C) Emmanuel Thomas-Maurin 2009-2011
+ *	TICKR - GTK-based Feed Reader - Copyright (C) Emmanuel Thomas-Maurin 2009-2012
  *	<manutm007@gmail.com>
  *
  * 	This program is free software: you can redistribute it and/or modify
@@ -18,9 +18,16 @@
 
 #include "tickr.h"
 
+#ifdef G_OS_WIN32
+FILE	*stdout_fp, *stderr_fp;
+#endif
+
 static TickerEnv	*env;
 static Resource		*resrc;
+static FList		*feed_list;
+static FList		*feed_selection;
 static Params		*prm;
+static int		instance_id = 0;
 static int		shift_counter = 0;
 #if USE_GUI
 static GtkWidget	*popup_menu;
@@ -31,16 +38,66 @@ static int		position_x_in_drwa;
 static GtkWidget	*main_hbox, *vbox_ticker, *vbox_clock;
 static int		speed_up_flag = FALSE;
 static int		speed_down_flag = FALSE;
-static int		instance_id = 0;
 
-#ifdef G_OS_WIN32
-FILE			*stdout_fp, *stderr_fp;
-#endif
+#define START_PAUSE_TICKER_WHILE_OPENING\
+	int	suspend_rq_bak;\
+	char	disable_popups_bak;\
+	suspend_rq_bak = env->suspend_rq;\
+	env->suspend_rq = TRUE;\
+	disable_popups_bak = get_params()->disable_popups;\
+	get_params()->disable_popups = 'n';
 
-/* prototypes for some static funcs */
+#define END_PAUSE_TICKER_WHILE_OPENING	\
+	get_params()->disable_popups = disable_popups_bak;\
+	env->suspend_rq = suspend_rq_bak;
+
+/* prototypes for a few static funcs */
 static gint shift2left_callback();
+static void check_time_load_resource(check_time_mode);
 
-#if USE_GUI
+TickerEnv *get_ticker_env()
+{
+	return env;
+}
+
+Resource *get_resource()
+{
+	return resrc;
+}
+
+FList *get_feed_list()
+{
+	return feed_list;
+}
+
+void set_feed_list(FList *list)
+{
+	feed_list = list;
+}
+
+FList *get_feed_selection()
+{
+	return feed_selection;
+}
+
+void set_feed_selection(FList *list)
+{
+	feed_selection = list;
+}
+
+Params *get_params()
+{
+	return prm;
+}
+
+int get_instance_id()
+{
+	return instance_id;
+}
+
+#if USE_GUI	/* maybe this compile #if should be removed because
+		 * it has been there and ***unused*** for a long time
+		 * and it probably breaks compile anyways */
 void toggle_speed_up_flag()
 {
 	speed_up_flag = TRUE;
@@ -55,9 +112,9 @@ void toggle_speed_down_flag()
 void check_main_win_always_on_top()
 {
 	if (prm->always_on_top == 'y')
-		gtk_window_set_keep_above(GTK_WINDOW(get_ticker_env()->win), TRUE);
+		gtk_window_set_keep_above(GTK_WINDOW(env->win), TRUE);
 	else
-		gtk_window_set_keep_above(GTK_WINDOW(get_ticker_env()->win), FALSE);
+		gtk_window_set_keep_above(GTK_WINDOW(env->win), FALSE);
 }
 
 #if USE_GUI
@@ -66,35 +123,120 @@ void check_main_win_always_on_top()
  */
 static void get_new_url2()
 {
+	START_PAUSE_TICKER_WHILE_OPENING
 	get_new_url(resrc);
+	END_PAUSE_TICKER_WHILE_OPENING
 }
 
 static void open_new_txt_file2()
 {
+	START_PAUSE_TICKER_WHILE_OPENING
 	open_new_txt_file(resrc);
+	END_PAUSE_TICKER_WHILE_OPENING
+}
+
+static void import_opml_file2()
+{
+	START_PAUSE_TICKER_WHILE_OPENING
+	import_opml_file();
+	END_PAUSE_TICKER_WHILE_OPENING
+}
+
+static void export_opml_file2()
+{
+	START_PAUSE_TICKER_WHILE_OPENING
+	export_opml_file();
+	END_PAUSE_TICKER_WHILE_OPENING
+}
+
+static void show_resource_info()
+{
+#define INFO_OPEN_TAG	""	/*"<b>"*/
+#define INFO_CLOSE_TAG	""	/*"</b>"*/
+	char	tmp[512];
+
+	START_PAUSE_TICKER_WHILE_OPENING
+	/* TODO: improve layout - use a table? */
+	if (resrc->type == RESRC_URL) {
+		snprintf(tmp, 511, "\n"
+			"Resource type:        "INFO_OPEN_TAG"%s Feed"INFO_CLOSE_TAG"\n\n"
+			"Feed title:                "INFO_OPEN_TAG"%s"INFO_CLOSE_TAG"\n\n"
+			"Feed URL:                "INFO_OPEN_TAG"%s"INFO_CLOSE_TAG"\n",
+			(resrc->format == RSS_2_0 ? "RSS 2.0" : (resrc->format == RSS_ATOM ? "Atom" : "RSS 1.0")),
+			resrc->feed_title, resrc->id);
+		info_win("Resource Properties", tmp, INFO, TRUE);
+	} else if (resrc->type == RESRC_FILE) {
+		snprintf(tmp, 511, "\n"
+			"Resource type:        "INFO_OPEN_TAG"File"INFO_CLOSE_TAG"\n\n"
+			"File name:               "INFO_OPEN_TAG"%s"INFO_CLOSE_TAG"\n",
+			resrc->id);
+		info_win("Resource Properties", tmp, INFO, TRUE);
+	} else
+		info_win("Resource Properties", "\nNo information available\n", INFO_ERROR, FALSE);
+	END_PAUSE_TICKER_WHILE_OPENING
 }
 
 static void modify_params2()
 {
+	START_PAUSE_TICKER_WHILE_OPENING
 	if (modify_params(prm) == 1)	/* 1 means we want to reopen the dialog */
 		modify_params2(prm);
+	END_PAUSE_TICKER_WHILE_OPENING
 }
 
 static void connection_settings2()
 {
-	int	suspend_rq_bak;
-	char	disable_popups_bak;
-
-	suspend_rq_bak = get_ticker_env()->suspend_rq;
-	get_ticker_env()->suspend_rq = TRUE;
-	disable_popups_bak = get_params()->disable_popups;	/* IS THIS ANY */
-	get_params()->disable_popups = 'n';			/* BETTER? */
-	if (connection_settings(AUTH_PAGE) == GTK_RESPONSE_OK) {
+	START_PAUSE_TICKER_WHILE_OPENING
+	if (connection_settings(AUTH_PAGE) == GTK_RESPONSE_OK)
 		current_feed();
-		get_ticker_env()->reload_rq = TRUE;
+	END_PAUSE_TICKER_WHILE_OPENING
+}
+
+static void import_params2()
+{
+	START_PAUSE_TICKER_WHILE_OPENING
+	import_params();
+	END_PAUSE_TICKER_WHILE_OPENING
+}
+
+static void export_params2()
+{
+	START_PAUSE_TICKER_WHILE_OPENING
+	export_params();
+	END_PAUSE_TICKER_WHILE_OPENING
+}
+
+static void pause_on_mouseover_enabled_warning_once()
+{
+	static int	first_run = -1;
+
+	if (prm->pause_on_mouseover == 'y') {
+		if (first_run == -1)
+			warning(FALSE, 1,
+				"Setting 'Pause ticker on mouse-over' is enabled. When so, playing/pausing\n"
+				"is always controlled by mouse pointer motions as well.");
+		first_run++;
+		first_run &= 1;
 	}
-	get_params()->disable_popups = disable_popups_bak;
-	get_ticker_env()->suspend_rq = suspend_rq_bak;
+}
+
+static void ticker_play()
+{
+	env->suspend_rq = FALSE;
+	pause_on_mouseover_enabled_warning_once();
+}
+
+static void ticker_pause()
+{
+	env->suspend_rq = TRUE;
+	pause_on_mouseover_enabled_warning_once();
+}
+
+static void ticker_reload()
+{
+	current_feed();
+	env->reload_rq = TRUE;
+	env->suspend_rq = FALSE;
 }
 
 static void first_feed2()
@@ -105,14 +247,6 @@ static void first_feed2()
 		info_win_wait("Single selection mode", INFO_WIN_WAIT_TIMEOUT);
 }
 
-static void last_feed2()
-{
-	if (env->selection_mode == MULTIPLE)
-		last_feed();
-	else
-		info_win_wait("Single selection mode", INFO_WIN_WAIT_TIMEOUT);
-}
-
 static void previous_feed2()
 {
 	if (env->selection_mode == MULTIPLE)
@@ -129,37 +263,12 @@ static void next_feed2()
 		info_win_wait("Single selection mode", INFO_WIN_WAIT_TIMEOUT);
 }
 
-static void show_resource_info()
+static void last_feed2()
 {
-#define INFO_OPEN_TAG	""	/*"<b>"*/
-#define INFO_CLOSE_TAG	""	/*"</b>"*/
-	char	tmp[512];
-	int	suspend_rq_bak;
-	char	disable_popups_bak;
-
-	/* TODO: improve layout - use a table? */
-	suspend_rq_bak = get_ticker_env()->suspend_rq;
-	get_ticker_env()->suspend_rq = TRUE;
-	disable_popups_bak = get_params()->disable_popups;
-	get_params()->disable_popups = 'n';
-	if (resrc->type == RESRC_URL) {
-		snprintf(tmp, 511, "\n"
-			"Resource type:        "INFO_OPEN_TAG"%s Feed"INFO_CLOSE_TAG"\n\n"
-			"Feed title:                "INFO_OPEN_TAG"%s"INFO_CLOSE_TAG"\n\n"
-			"Feed URL:                "INFO_OPEN_TAG"%s"INFO_CLOSE_TAG"\n",
-			(resrc->format == RSS_2_0 ? "RSS 2.0" : (resrc->format == RSS_ATOM ? "Atom" : "RSS 1.0")),
-			resrc->feed_title, resrc->id);
-		info_win("Resource Properties", tmp, INFO, TRUE);
-	} else if (resrc->type == RESRC_FILE) {
-		snprintf(tmp, 511, "\n"
-			"Resource type:        "INFO_OPEN_TAG"File"INFO_CLOSE_TAG"\n\n"
-			"File name:               "INFO_OPEN_TAG"%s"INFO_CLOSE_TAG"\n",
-			resrc->id);
-		info_win("Resource Properties", tmp, INFO, TRUE);
-	} else
-		info_win("Resource Properties", "\nNo information available\n", INFO_ERROR, FALSE);
-	get_params()->disable_popups = disable_popups_bak;
-	get_ticker_env()->suspend_rq = suspend_rq_bak;
+	if (env->selection_mode == MULTIPLE)
+		last_feed();
+	else
+		info_win_wait("Single selection mode", INFO_WIN_WAIT_TIMEOUT);
 }
 
 #ifdef G_OS_WIN32
@@ -210,23 +319,6 @@ static void easily_link_with_browser()
 }
 #endif
 
-static void ticker_play()
-{
-	env->suspend_rq = FALSE;
-}
-
-static void ticker_pause()
-{
-	env->suspend_rq = TRUE;
-}
-
-static void ticker_reload()
-{
-	current_feed();
-	env->reload_rq = TRUE;
-	env->suspend_rq = FALSE;
-}
-
 static int get_visible_link()
 {
 	int	i, location_on_surface;
@@ -256,23 +348,21 @@ static void open_link()
 	if (prm->open_link_cmd[0] == '\0') {
 #ifndef G_OS_WIN32
 		/* TODO: should look for default browser */
-		warning("Can't launch Browser: no command is defined.\n"
-			"Please set the 'Open in Browser' option in the Preferences window.",
-			"", "", "", FALSE);
+		warning(FALSE, 2, "Can't launch Browser: no command is defined.\n",
+			"Please set the 'Open in Browser' option in the Preferences window.");
 		return;
 #else
 		easily_link_with_browser();
 		if (prm->open_link_cmd[0] == '\0') {
-			warning("Can't launch Browser: no command is defined.\n"
-				"Please set the 'Open in Browser' option in the Preferences window.",
-				"", "", "", FALSE);
+			warning(FALSE, 2, "Can't launch Browser: no command is defined.\n",
+				"Please set the 'Open in Browser' option in the Preferences window.");
 			return;
 		}
 #endif
 	}
 
 	if (env->active_link [0] == '\0') {
-		warning("No link found", "", "", "", FALSE);
+		warning(FALSE, 1, "No link found");
 		return;
 	}
 
@@ -297,7 +387,7 @@ static void open_link()
 	argv[j] = env->active_link;
 	argv[j + 1] = NULL;
 	if (!g_spawn_async(NULL, argv, NULL, G_SPAWN_SEARCH_PATH, NULL, NULL, &pid, &error)) {
-		warning(APP_NAME": Can't create process ", argv[0], " - ", error->message, FALSE);
+		warning(FALSE, 3, APP_NAME": Can't create process ", argv[0], " - ", error->message);
 #ifndef G_OS_WIN32
 		info_win(APP_NAME" - Warning", "Please check the 'Open in Browser' option in the Preferences window.",
 			INFO_WARNING, FALSE);
@@ -316,10 +406,9 @@ static void open_link2()
 	open_link();
 }
 
-static gint left_click_on_drawing_area(GtkWidget *widget, GdkEventButton *event, gpointer unused)
+static gint left_click_on_drawing_area(GtkWidget *widget, GdkEventButton *event)
 {
 	widget = widget;
-	unused = unused;
 	if (event->type == GDK_BUTTON_PRESS && event->button == 1) {	/* 1 = mouse left button */
 		/* get pointer x location on drawing_area */
 		position_x_in_drwa = event->x;
@@ -330,10 +419,9 @@ static gint left_click_on_drawing_area(GtkWidget *widget, GdkEventButton *event,
 		return FALSE;
 }
 
-static gint right_click_on_drawing_area(GtkWidget *widget, GdkEventButton *event, gpointer unused)
+static gint right_click_on_drawing_area(GtkWidget *widget, GdkEventButton *event)
 {
 	widget = widget;
-	unused = unused;
 	if (event->type == GDK_BUTTON_PRESS && event->button == 3) {	/* 3 = mouse right button */
 		/* popup main menu */
 		gtk_menu_popup(GTK_MENU(popup_menu), NULL, NULL, NULL, NULL, event->button, event->time);
@@ -342,43 +430,81 @@ static gint right_click_on_drawing_area(GtkWidget *widget, GdkEventButton *event
 		return FALSE;
 }
 
-/* pause ticker on mouseover */
-static gint mouse_over_drawing_area(GtkWidget *widget, GdkEvent *event, gpointer unused)
+static const char *get_win_title_tooltip_text()
+{
+	static char	tmp1[2][256 + 64], tmp2[2][64];
+	static int	i = -1;
+
+	/* to allow 2 simultaneous calls */
+	i++;
+	i &= 1;
+
+	if (resrc->type == RESRC_URL)
+		str_n_cpy(tmp1[i], resrc->feed_title, 256);
+	else if (resrc->type == RESRC_FILE)
+		str_n_cpy(tmp1[i], resrc->id, 256);
+	else
+		str_n_cpy(tmp1[i], "No resource", 256);
+	snprintf(tmp2[i], 64, "  |  %s-%s", APP_NAME, APP_VERSION_NUMBER);
+	return (const char *)str_n_cat(tmp1[i], tmp2[i], 63);
+}
+
+/* pause ticker when mouse pointer is over (opened) popup menu */
+static gint mouse_over_opened_popup_menu(GtkWidget *widget, GdkEvent *event)
 {
 	widget = widget;
-	unused = unused;
 	if (prm->pause_on_mouseover == 'y') {
-		if (event->type == GDK_ENTER_NOTIFY)
+		if (event->type == GDK_EXPOSE)
 			env->suspend_rq = TRUE;
 		else if (event->type == GDK_LEAVE_NOTIFY)
 			env->suspend_rq = FALSE;
 	}
-	if (resrc->type == RESRC_URL)
-		gtk_widget_set_tooltip_text(widget, resrc->feed_title);
-	else if (resrc->type == RESRC_FILE)
-		gtk_widget_set_tooltip_text(widget, resrc->id);
-	return TRUE;
+	return FALSE;
 }
 
-static gint mouse_wheel_scroll_on_drawing_area(GtkWidget *widget, GdkEvent *event, gpointer unused)
+/* pause ticker on mouseover */
+static gint mouse_over_drawing_area(GtkWidget *widget, GdkEvent *event)
+{
+	widget = widget;
+	if (event->type == GDK_ENTER_NOTIFY || event->type == GDK_LEAVE_NOTIFY) {
+		if (prm->pause_on_mouseover == 'y') {
+			if (event->type == GDK_ENTER_NOTIFY)
+				env->suspend_rq = TRUE;
+			else if (event->type == GDK_LEAVE_NOTIFY)
+				env->suspend_rq = FALSE;
+		}
+		gtk_widget_set_tooltip_text(widget, get_win_title_tooltip_text());
+		gtk_tooltip_trigger_tooltip_query(gdk_display_get_default());
+		return TRUE;
+	} else
+		return FALSE;
+}
+
+static gint mouse_wheel_scroll_on_drawing_area(GtkWidget *widget, GdkEvent *event)
 {
 	widget = widget;
-	unused = unused;
 	if (event->type == GDK_SCROLL) {
-		env->suspend_rq = FALSE;
-		if (event->scroll.direction == GDK_SCROLL_UP) {
-			if (prm->mouse_wheel_scroll == 's')
+		if (prm->mouse_wheel_scroll == 's') {
+			if (event->scroll.direction == GDK_SCROLL_UP)
 				toggle_speed_up_flag();
-			else if (prm->mouse_wheel_scroll == 'f')
-				next_feed2();
-		} else if (event->scroll.direction == GDK_SCROLL_DOWN) {
-			if (prm->mouse_wheel_scroll == 's')
+			else if (event->scroll.direction == GDK_SCROLL_DOWN)
 				toggle_speed_down_flag();
-			else if (prm->mouse_wheel_scroll == 'f')
-				previous_feed2();
+			env->suspend_rq = FALSE;
+			return TRUE;
+		} else if (prm->mouse_wheel_scroll == 'f') {
+			if (env->selection_mode == MULTIPLE) {
+				if (event->scroll.direction == GDK_SCROLL_UP)
+					quick_feed_picker(GDK_SCROLL_UP);
+				else if (event->scroll.direction == GDK_SCROLL_DOWN)
+					quick_feed_picker(GDK_SCROLL_DOWN);
+				env->suspend_rq = FALSE;
+			} else
+				warning(FALSE, 2, "Single selection mode\n",
+					"(You have set 'Mouse wheel scrolling apply to: Feed')");
+			return TRUE;
 		}
 	}
-	return TRUE;
+	return FALSE;
 }
 
 /*
@@ -395,15 +521,9 @@ static GtkItemFactoryEntry popup_menu_item[] = {
 
 	{"/File/sep",		NULL, NULL, 0, "<Separator>", NULL},
 
-	{"/File/_Import Feed List (OPML)", "<control>I", import_opml_file, 0, NULL, NULL},
+	{"/File/_Import Feed List (OPML)", "<control>I", import_opml_file2, 0, NULL, NULL},
 
-	{"/File/_Export Feed List (OPML)", "<control>E", export_opml_file, 0, NULL, NULL},
-
-	{"/File/sep",		NULL, NULL, 0, "<Separator>", NULL},
-
-	{"/File/Import Preferences", "<control>", import_params, 0, NULL, NULL},
-
-	{"/File/Export Preferences", "<control>", export_params, 0, NULL, NULL},
+	{"/File/_Export Feed List (OPML)", "<control>E", export_opml_file2, 0, NULL, NULL},
 
 	{"/File/sep",		NULL, NULL, 0, "<Separator>", NULL},
 
@@ -423,6 +543,12 @@ static GtkItemFactoryEntry popup_menu_item[] = {
 	{"/Edit/Connection Settings", "<control>", connection_settings2, 0, "<StockItem>",
 				(gconstpointer)GTK_STOCK_CONNECT},
 
+	{"/Edit/sep",		NULL, NULL, 0, "<Separator>", NULL},
+
+	{"/Edit/Import Preferences", "<control>", import_params2, 0, NULL, NULL},
+
+	{"/Edit/Export Preferences", "<control>", export_params2, 0, NULL, NULL},
+
 	{"/_Control",		NULL, NULL, 0, "<Branch>", NULL},
 
 	{"/Control/Open Link in _Browser", "<control>B", open_link2, 0, "<StockItem>",
@@ -535,7 +661,6 @@ static int compute_surface_and_win()
 	char		cfname[FONT_NAME_MAXLEN + 1], cfsize[FONT_SIZE_MAXLEN + 1];
 	gint		height1, height2;
 	int		size, render_exit_status, i;
-	char		tmp[80];
 
 	gtk_window_set_keep_above(GTK_WINDOW(env->win), FALSE);
 	gtk_window_set_skip_taskbar_hint(GTK_WINDOW(env->win), FALSE);
@@ -597,29 +722,30 @@ static int compute_surface_and_win()
 	if (render_exit_status != OK && render_exit_status != RENDER_NO_RESOURCE) {
 		switch(render_exit_status) {
 			case RENDER_NULL_ENDINGSTR:
-				warning("render_stream_to_surface():", "ending string = NULL", "", "", FALSE);
+				warning(FALSE, 1, "render_stream_to_surface(): ending string = NULL");
 				break;
 			case RENDER_GETLINE_ERROR:
-				warning("render_stream_to_surface():", "getline() error", "", "", FALSE);
+				warning(FALSE, 1, "render_stream_to_surface(): getline() error");
 				break;
 			case RENDER_LINE_TOO_LONG:
-				warning("render_stream_to_surface():", "line too long\n", "", "", FALSE);
+				warning(FALSE, 1, "render_stream_to_surface(): line too long\n");
 				break;
 			case RENDER_CAIRO_IMAGE_SURFACE_TOO_WIDE:
-				big_error(RENDER_CAIRO_IMAGE_SURFACE_TOO_WIDE, "render_stream_to_surface():",
-					"cairo image surface too wide (> 32 K pixels)", "", "");
+				big_error(RENDER_CAIRO_IMAGE_SURFACE_TOO_WIDE, 1, "render_stream_to_surface(): "
+					"cairo image surface too wide (> 32 K pixels)");
 				break;
 			case RENDER_CREATE_CAIRO_IMAGE_SURFACE_ERROR:
-				big_error(RENDER_CREATE_CAIRO_IMAGE_SURFACE_ERROR, "render_stream_to_surface():",
-					"can't create cairo image surface", "", "");
+				big_error(RENDER_CREATE_CAIRO_IMAGE_SURFACE_ERROR, 1, "render_stream_to_surface(): "
+					"can't create cairo image surface");
 				break;
-			default: warning("render_stream_to_surface():", "unknown error", "", "", FALSE);
+			default: warning(FALSE, 2, "render_stream_to_surface(): unknown error ",
+					itoa2(render_exit_status));
 				break;
 		}
 	}
 	if (env->c_surf == NULL)
-		big_error(render_exit_status,
-			"render_stream_to_surface():", "cairo image surface = NULL", "", "");
+		big_error(render_exit_status, 1,
+			"render_stream_to_surface(): cairo image surface = NULL");
 	env->surf_width = cairo_image_surface_get_width(env->c_surf);
 	env->surf_height = cairo_image_surface_get_height(env->c_surf);
 	env->drwa_height = (MIN(env->surf_height, env->screen_h));
@@ -627,13 +753,7 @@ static int compute_surface_and_win()
 	 * window layout stuff
 	 */
 	/* win title */
-	if (resrc->type == RESRC_URL)
-		snprintf(tmp, 80, "%s-%s  |  %s", APP_NAME, APP_VERSION_NUMBER, resrc->feed_title);
-	else if (resrc->type == RESRC_FILE)
-		snprintf(tmp, 80, "%s-%s  |  %s", APP_NAME, APP_VERSION_NUMBER, resrc->id);
-	else
-		snprintf(tmp, 80, "%s-%s  |  %s", APP_NAME, APP_VERSION_NUMBER, "No resource");
-	gtk_window_set_title(GTK_WINDOW(env->win), tmp);
+	gtk_window_set_title(GTK_WINDOW(env->win), get_win_title_tooltip_text());
 	/*
 	 * when window-always-on-top is disabled, the following code needs to be run
 	 * only twice at program startup (ie once after gtk_widget_show_all() has been
@@ -769,7 +889,7 @@ static gint shift2left_callback()
     			if (env->selection_mode == SINGLE && env->reload_rq)
 				load_resource(resrc, NULL);
 			else {
-				while ((i = load_resource(resrc, get_selected_url_list())) != OK) {
+				while ((i = load_resource(resrc, feed_selection)) != OK) {
 					if (i == CONNECT_TOO_MANY_ERRORS && env->selection_mode == MULTIPLE) {
 						if (get_params()->disable_popups == 'n') {
 							snprintf(tmp, 256,
@@ -830,7 +950,7 @@ static gint get_win_position()	/* only if win is 'draggable' */
 /*
  * reload stuff every <resrc->rss_ttl * 60> seconds
  */
-void check_time_load_resource(check_time_mode mode)
+static void check_time_load_resource(check_time_mode mode)
 {
 	static unsigned long	elapsed_time_in_sec;
 
@@ -846,27 +966,12 @@ void check_time_load_resource(check_time_mode mode)
 	}
 }
 
-gint check_time_load_resource2()
+static gint check_time_load_resource2()
 {
 	check_time_load_resource(TIME_CHECK);
 	return TRUE;
 }
 
-TickerEnv *get_ticker_env()
-{
-	return env;
-}
-
-Resource *get_resource()
-{
-	return resrc;
-}
-
-Params *get_params()
-{
-	return prm;
-}
-
 static void quit_with_cli_info(tickr_error_code error_code)
 {
 	if (resrc->fp != NULL)
@@ -902,26 +1007,24 @@ static void print_license()
 	fprintf(STD_OUT, "%s\n", get_license_str2());
 }
 
-int get_instance_id()
-{
-	return instance_id;
-}
-
 /* reload resource as soon as scrolling has started to update all display params
- * TODO: reset open stream to begining and recompute instead of reload (which
- * is useless) -> must 1st make sure this doesn't break anything
+ * TODO: reset open stream to begining and recompute instead of reloading (which
+ * is useless) -> must first make sure this doesn't break anything
  */
 gint update_everything()
 {
 	if (shift_counter > 4) {
-		current_feed();
+		if (env->selection_mode == MULTIPLE)
+			current_feed();
+		else
+			env->reload_rq = TRUE;
 		return FALSE;
 	} else
 		return TRUE;
 }
 
 #ifdef G_OS_WIN32
-/* this is meant to be used with the new gtk runtime */
+/* this is meant to be used with the new GTK/GLib-win32 runtime */
 static int init_win32_mmtimer()
 {
 	TIMECAPS	tc;
@@ -937,6 +1040,54 @@ static int init_win32_mmtimer()
 		return -1;
 	}
 }
+
+static void create_win32_logfiles()
+{
+	time_t	time2 = time(NULL);
+
+	STD_OUT = open_new_datafile_with_name(STDOUT_FILENAME1, "wb");
+	STD_ERR = open_new_datafile_with_name(STDERR_FILENAME1, "wb");
+	fprintf(STD_OUT, "%s", ctime(&time2));
+	fprintf(STD_ERR, "%s", ctime(&time2));
+}
+
+/* swap win32 log files every hour to prevent generating huge ones */
+static gint swap_win32_logfiles()
+{
+	static unsigned long	elapsed_time_in_sec = 0;
+	static int		counter = 0;
+	int			suspend_rq_bak;
+	time_t			time2 = time(NULL);
+
+	if ((++elapsed_time_in_sec) >= (unsigned long)3600) {
+		elapsed_time_in_sec = 0;
+		counter++;
+		counter &= 1;
+		suspend_rq_bak = env->suspend_rq;
+		env->suspend_rq = TRUE;
+		if (STD_OUT != NULL) {
+			if (fclose(STD_OUT) != 0)
+				big_error(WIN32V_ERROR, 2, "Can't close STD_OUT: ", strerror(errno));
+			STD_OUT = NULL;
+		}
+		if (STD_ERR != NULL) {
+			if (fclose(STD_ERR) != 0)
+				big_error(WIN32V_ERROR, 2, "Can't close STD_ERR: ", strerror(errno));
+			STD_ERR = NULL;
+		}
+		if (counter == 0) {
+			STD_OUT = open_new_datafile_with_name(STDOUT_FILENAME1, "wb");
+			STD_ERR = open_new_datafile_with_name(STDERR_FILENAME1, "wb");
+		} else {
+			STD_OUT = open_new_datafile_with_name(STDOUT_FILENAME2, "wb");
+			STD_ERR = open_new_datafile_with_name(STDERR_FILENAME2, "wb");
+		}
+		fprintf(STD_OUT, "%s", ctime(&time2));
+		fprintf(STD_ERR, "%s", ctime(&time2));
+		env->suspend_rq = suspend_rq_bak;
+	}
+	return TRUE;
+}
 #endif
 
 int main(int argc, char *argv[])
@@ -983,26 +1134,25 @@ int main(int argc, char *argv[])
 
 #ifdef G_OS_WIN32
 	if ((i = WSAStartup(MAKEWORD(2, 2), &wsadata)) != 0)
-		big_error(WIN32V_ERROR, "WSAStartup() error ", itoa2(i), "", "");
+		big_error(WIN32V_ERROR, 2, "WSAStartup() error ", itoa2(i));
 	else if (LOBYTE(wsadata.wVersion) != 2 || HIBYTE(wsadata.wVersion) != 2) {
 		WSACleanup();
-		big_error(WIN32V_ERROR, "Couldn't find a usable version of Winsock.dll", "", "", "");
+		big_error(WIN32V_ERROR, 1, "Couldn't find a usable version of Winsock.dll");
 	} else if (get_progfiles_dir() == NULL)
-		big_error(WIN32V_ERROR, "Can't find Program Files directory", "", "", "");
+		big_error(WIN32V_ERROR, 1, "Can't find Program Files directory");
 	else if (get_appdata_dir() == NULL)
-		big_error(WIN32V_ERROR, "Can't find Application Data directory", "", "", "");
+		big_error(WIN32V_ERROR, 1, "Can't find Application Data directory");
 	else if (init_win32_mmtimer() != 0)
 		if (question_win("Can't initialize win32 multimedia timer. "
 				"Scrolling may be very slow. Continue ?") == NO)
 			exit(WIN32V_ERROR);
 #endif
 	/*
-	 * create news dir in user home dir if it doesn't exist
+	 * create dir in user home dir if it doesn't exist
 	 */
 	g_mkdir(get_datadir_full_path(), S_IRWXU);
 #ifdef G_OS_WIN32
-	STD_OUT = open_new_datafile_with_name(STDOUT_FILENAME, "wb+");
-	STD_ERR = open_new_datafile_with_name(STDERR_FILENAME, "wb+");
+	create_win32_logfiles();
 #endif
 	/*
 	 * get help, show license, set instance id or check available system fonts
@@ -1028,7 +1178,7 @@ int main(int argc, char *argv[])
 		dump_font_list();
 		return 0;
 	}
-	set_news_icon_to_dialog(GTK_WINDOW(env->win));
+	set_tickr_icon_to_dialog(GTK_WINDOW(env->win));
 	/*
 	 * create rss icon
 	 */
@@ -1108,21 +1258,25 @@ int main(int argc, char *argv[])
 			quit_with_cli_info(RESOURCE_NONE);
 	}
 	compute_auth_and_proxy_str();
-	init_url_list();
-	if ((i = load_url_list(get_url_list())) == OK)
-		save_url_list(get_url_list());
-	init_selected_url_list();
-	j = load_selected_url_list(get_selected_url_list());
+	/*
+	 * feed list stuff
+	 */
+	if ((i = f_list_load_from_file(&feed_list, NULL)) == OK) {
+		feed_list = f_list_sort(feed_list);
+		feed_list = f_list_first(feed_list);
+		f_list_save_to_file(feed_list, NULL);
+	}
+	j = build_feed_selection_from_feed_list();
 	if (n_resources == 0 && env->selection_mode == MULTIPLE && i == OK && j == OK)
 		fprintf(STD_OUT, "Will use feed selection\n");
 	else {
 		if (env->selection_mode == MULTIPLE && (i != OK || j != OK)) {
 			if (j == SELECTION_EMPTY)
-				warning("No feed selected", "-",
-					"Switching to single selection mode", "", TRUE);
+				warning(TRUE, 1, "No feed selected - "
+					"Switching to single selection mode");
 			else if (j == SELECTION_ERROR)
-				warning("No feed selection available", "-",
-					"Switching to single selection mode", "", TRUE);
+				warning(TRUE, 1, "No feed selection available - "
+					"Switching to single selection mode");
 		}
 		env->selection_mode = SINGLE;
 		if (n_resources == 0) {
@@ -1137,7 +1291,7 @@ int main(int argc, char *argv[])
 		}
 	}
 	first_feed();
-	if (load_resource(resrc, get_selected_url_list()) != OK)
+	if (load_resource(resrc, feed_selection) != OK)
 		if (RESOURCE_NONE_QUIT)
 			quit_with_cli_info(RESOURCE_NONE);
 	resrc->rss_ttl = prm->rss_refresh;
@@ -1166,6 +1320,8 @@ int main(int argc, char *argv[])
 	g_signal_connect(G_OBJECT(env->drw_a), "button-press-event", G_CALLBACK(right_click_on_drawing_area), NULL);
 	g_signal_connect(G_OBJECT(env->drw_a), "enter-notify-event", G_CALLBACK(mouse_over_drawing_area), NULL);
 	g_signal_connect(G_OBJECT(env->drw_a), "leave-notify-event", G_CALLBACK(mouse_over_drawing_area), NULL);
+	g_signal_connect(G_OBJECT(popup_menu), "expose-event", G_CALLBACK(mouse_over_opened_popup_menu), NULL);
+	g_signal_connect(G_OBJECT(popup_menu), "leave-notify-event", G_CALLBACK(mouse_over_opened_popup_menu), NULL);
 	g_signal_connect(G_OBJECT(env->drw_a), "scroll-event", G_CALLBACK(mouse_wheel_scroll_on_drawing_area), NULL);
 #endif
 	vbox_ticker = gtk_vbox_new(FALSE, 0);	/* vbox_ticker is only used to have a v-centered ticker */
@@ -1201,6 +1357,12 @@ int main(int argc, char *argv[])
 	g_timeout_add_full(G_PRIORITY_DEFAULT, 500, update_win_dims, NULL, NULL);
 
 	g_timeout_add_full(G_PRIORITY_DEFAULT, 100, update_everything, NULL, NULL);
+	/*
+	 * check every sec until elapsed time >= 1 hour then swap win32 log files to prevent generating huge ones
+	 */
+#ifdef G_OS_WIN32
+	g_timeout_add_full(G_PRIORITY_DEFAULT, 1000, swap_win32_logfiles, NULL, NULL);
+#endif
 
 	env->suspend_rq = FALSE;
 	env->compute_rq = FALSE;
