@@ -1,5 +1,5 @@
 /*
- *	TICKR - GTK-based Feed Reader - Copyright (C) Emmanuel Thomas-Maurin 2009-2011
+ *	TICKR - GTK-based Feed Reader - Copyright (C) Emmanuel Thomas-Maurin 2009-2012
  *	<manutm007@gmail.com>
  *
  * 	This program is free software: you can redistribute it and/or modify
@@ -23,10 +23,10 @@
 extern FILE	*stdout_fp, *stderr_fp;
 #endif
 static char	*opml_str_global;
+static char	tmp_url[FILE_NAME_MAXLEN + 1], tmp_str[256];
 
-static gint esc_key_pressed(GtkWidget *dialog2, GdkEventKey *event, gpointer unused)
+static gint esc_key_pressed(GtkWidget *dialog2, GdkEventKey *event)
 {
-	unused = unused;
 	if (event->keyval == GDK_Escape) {
 		gtk_dialog_response(GTK_DIALOG(dialog2), GTK_RESPONSE_CANCEL);
 		return TRUE;
@@ -43,52 +43,77 @@ static void force_quit_dialog(GtkWidget *dialog2)
  * importing
  */
 
+static int *get_feed_counter()
+{
+	static int	feed_counter;
+
+	return &feed_counter;
+}
+
+static void zero_feed_counter()
+{
+	*get_feed_counter() = 0;
+}
+
+static void inc_feed_counter()
+{
+	*get_feed_counter() += 1;
+}
+
 void import_opml_file()
 {
-	char		*file_name, *listfname;
-	FILE		*fp;
-	/* same as stuff in news_rsswin.c */
-	char		url_array[NURLMAX][FILE_NAME_MAXLEN + 1];
-	char		*p_url[NURLMAX + 1];
-	int		suspend_rq_bak, i;
+	char	*opml_file_name, *url_list_file_name;
+	FList	*node;
+	FILE	*fp;
+	int	status =  OPML_ERROR;
 
-	if ((file_name = pick_opml_file())[0] != '\0') {
-		listfname = (char *)get_datafile_full_name_from_name(URLLIST);
-		if ((fp = g_fopen(listfname, "rb")) != NULL) {
+	if ((opml_file_name = pick_opml_file())[0] != '\0') {
+		url_list_file_name = l_str_new(get_datafile_full_name_from_name(URL_LIST_FILE));
+		if ((fp = g_fopen(url_list_file_name, "rb")) != NULL) {
 			fclose(fp);
 			if (question_win("Imported URLs will be merged with currently saved ones. "
-					"Continue ?") == NO)
+					"Continue ?") == NO) {
+				l_str_free(url_list_file_name);
 				return;
+			}
+		} else if ((fp = g_fopen(url_list_file_name, "wb")) != NULL)
+			fclose(fp);
+		else {
+			warning(FALSE, 4, "Can't create URL list ", url_list_file_name, ": ", strerror(errno));
+			return;
 		}
-		suspend_rq_bak = get_ticker_env()->suspend_rq;
-		get_ticker_env()->suspend_rq = TRUE;
-		win_with_spinner(WIN_WITH_SPINNER_OPEN,
-			"Importing data from OPML file, please wait...\n"
-			"(updating may take some time)");
+		win_with_progress_bar(WIN_WITH_PROGRESS_BAR_OPEN,
+			"    Importing (and updating) data from OPML file, please wait...    ");
+		zero_feed_counter();
+		get_ticker_env()->selection_mode = MULTIPLE;
 		opml_str_global = l_str_new(NULL);
-		if (parse_opml_xml_file(file_name) == OK) {
-			if ((fp = g_fopen(listfname, "ab")) != NULL) {
+		if (parse_opml_xml_file(opml_file_name) == OK)
+			if ((fp = g_fopen(url_list_file_name, "ab")) != NULL) {
 				fprintf(fp, "\n%s\n", opml_str_global);
 				fclose(fp);
-				for (i = 0; i < NURLMAX; i++)
-					p_url[i] = url_array[i];
-				p_url[NURLMAX] = NULL;
-				if (load_url_list(p_url) == OK) {
-					sort_url_list(p_url, 1);
-					save_url_list(p_url);
-					load_selected_url_list(init_selected_url_list());
-					l_str_free(opml_str_global);
-					win_with_spinner(WIN_WITH_SPINNER_CLOSE, NULL);
-					get_ticker_env()->suspend_rq = suspend_rq_bak;
-					info_win(APP_NAME, "\nFeed list has been imported\n",
-						INFO, FALSE);
-					return;
+				if (f_list_load_from_file(&node, NULL) == OK) {
+					node = f_list_sort(node);
+					if (f_list_save_to_file(node, NULL) == OK) {
+						if (IS_FLIST(get_feed_list()))
+							f_list_free_all(get_feed_list());
+						set_feed_list(node);
+						status = OK;
+					}
 				}
 			}
-		}
+		l_str_free(url_list_file_name);
 		l_str_free(opml_str_global);
-		win_with_spinner(WIN_WITH_SPINNER_CLOSE, NULL);
-		get_ticker_env()->suspend_rq = suspend_rq_bak;
+		win_with_progress_bar(WIN_WITH_PROGRESS_BAR_CLOSE, NULL);
+		if (status == OK) {
+			/*snprintf(tmp_str, 256, "\nFeed list (%d URLs) has been imported\n",
+				*get_feed_counter());
+			info_win(APP_NAME, tmp_str, INFO, FALSE);*/
+			/* ok like that ? */
+			snprintf(tmp_str, 256, "\nFeed list (%d URLs) has been imported. "
+				"Open the Feed Picker window ?\n", *get_feed_counter());
+			if (question_win(tmp_str) == YES)
+				get_new_url(get_resource());
+		}
 	}
 }
 
@@ -107,7 +132,7 @@ char *pick_opml_file()
 			GTK_STOCK_OK, GTK_RESPONSE_OK,
 			NULL);
 
-	set_news_icon_to_dialog(GTK_WINDOW(dialog));
+	set_tickr_icon_to_dialog(GTK_WINDOW(dialog));
 	gtk_window_set_position(GTK_WINDOW(dialog), GTK_WIN_POS_CENTER);
 
 	g_signal_connect(G_OBJECT(dialog), "key-press-event", G_CALLBACK(esc_key_pressed), NULL);
@@ -140,15 +165,14 @@ int parse_opml_xml_file(const char *file_name)
 
 	fprintf(STD_OUT, "Parsing OPML file... ");
 	if ((doc = xmlParseFile(file_name)) == NULL) {
-		warning("Can't parse XML file:", xmlGetLastError()->message,
-			"", "", FALSE);
+		warning(FALSE, 2, "Can't parse XML file: ", xmlGetLastError()->message);
 		return XML_UNPARSABLE;
 	} else if ((cur_node = xmlDocGetRootElement(doc)) == NULL) {
-		warning("Empty XML document:", file_name, "", "", FALSE);
+		warning(FALSE, 2, "Empty XML document: ", file_name);
 		xmlFreeDoc(doc);
 		return XML_EMPTY;
 	} else if (xmlStrcmp(cur_node->name, (const xmlChar *)"opml") != 0) {
-		warning("Not an OPML document:", file_name, "", "", FALSE);
+		warning(FALSE, 2, "Not an OPML document: ", file_name);
 		xmlFreeDoc(doc);
 		return OPML_ERROR;
 	}
@@ -169,12 +193,12 @@ int parse_opml_xml_file(const char *file_name)
 	}
 	if (body_element == YES && outline_element == YES) {
 		get_opml_selected_element(cur_node_start, "outline", "type");
-		fprintf(STD_OUT, "done\n");
+		fprintf(STD_OUT, "Done\n");
 		xmlFreeDoc(doc);
 		return OK;
 	} else {
-		warning("Couldn't find all required OPML elements in:",
-			file_name, "", "", FALSE);
+		warning(FALSE, 2, "Couldn't find all required OPML elements in: ",
+			file_name);
 		xmlFreeDoc(doc);
 		return OPML_ERROR;
 	}
@@ -201,13 +225,23 @@ void get_opml_selected_element(xmlNode *some_node, const char *selected_element,
 						unesc_str = g_uri_unescape_string((const char *)str2, NULL);
 						opml_str_global = l_str_cat(opml_str_global, (const char*)unesc_str);
 						/* get feed title from feed url - ok like that? */
-						if (get_feed_info((const char *)unesc_str, feed_title, NULL, NULL) == OK) {
-							if (feed_title[0] != '\0') {
-								opml_str_global = l_str_cat(opml_str_global, TITLE_TAG_STR);
-								opml_str_global = l_str_cat(opml_str_global, feed_title);
-							}
-						}
+						str_n_cpy(tmp_url, unesc_str, FILE_NAME_MAXLEN);
+/* TODO: double-check following 2 lines hack */
+						if (fetch_resource(tmp_url, get_datafile_full_name_from_name(TMP1),
+								tmp_url) == OK)
+							if (get_feed_info(get_datafile_full_name_from_name(TMP1),
+									feed_title, NULL, NULL) == OK)
+								if (feed_title[0] != '\0') {
+									opml_str_global = l_str_cat(opml_str_global,
+										TITLE_TAG_STR);
+									opml_str_global = l_str_cat(opml_str_global,
+										feed_title);
+								}
 						opml_str_global = l_str_cat(opml_str_global, "\n");
+						inc_feed_counter();
+						snprintf(tmp_str, 256, "%d feeds imported so far, please wait...",
+							*get_feed_counter());
+						win_with_progress_bar(WIN_WITH_PROGRESS_BAR_PULSE, tmp_str);
 						g_free(unesc_str);
 						xmlFree(str2);
 					}
@@ -224,28 +258,22 @@ void get_opml_selected_element(xmlNode *some_node, const char *selected_element,
  */
 void export_opml_file()
 {
-	/* same as stuff in news_rsswin.c */
-	char	url_array[NURLMAX + 1][FILE_NAME_MAXLEN + 1];
-	char	*p_url[NURLMAX + 1];
+	FList	*node;
 	char	*str;
-	int	i;
 
-	for (i = 0; i < NURLMAX - 1; i++)
-		p_url[i] = url_array[i];
-	p_url[NURLMAX] = NULL;
-
-	if (load_url_list(p_url) == OK) {
-		str = create_opml_str_from_url_list(p_url);
+	if (f_list_load_from_file(&node, NULL) == OK) {
+		str = create_opml_str_from_feed_list_node(node);
 		save_str_as_opml_file(str);
 		l_str_free(str);
+		f_list_free_all(node);
 	}
 }
 
 /* must l_str_free() opml_str afterwards */
-char *create_opml_str_from_url_list(char **url_list)
+char *create_opml_str_from_feed_list_node(FList *node)
 {
-#define OPML_TITLE	APP_NAME" Feed List"
-#define STR_SIZE	(8 * 1024)
+#define OPML_TITLE	APP_NAME"-"APP_VERSION_NUMBER" Feed List"
+#define STR_SIZE	(4 * 1024)
 
 	char 	*opml_header =
 		"<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n"
@@ -259,37 +287,21 @@ char *create_opml_str_from_url_list(char **url_list)
 	char 	*opml_footer =
 		"  </body>\n"
 		"</opml>\n";
-	char	*opml_str, feed_title[FEED_TITLE_MAXLEN + 1], tmp[STR_SIZE];
-	gchar	*p, *esc_str;
-	int	i;
+	char	*opml_str, tmp[STR_SIZE];
+	gchar	*esc_str1, *esc_str2;
 
 	snprintf(tmp, STR_SIZE, opml_header, OPML_TITLE);
 	opml_str = l_str_new(tmp);
-
-	/* TODO: is escape stuff good? / should title be searched again for each feed?
-	*/
-	for (i = 0; i < NURLMAX && url_list[i] != NULL; i++) {
-		url_list[i] = url_list[i] + 1;	/* we skip 1st char = (UN)SELECTED_URL_CHAR */
-		if (!g_utf8_validate(url_list[i], -1, NULL)) {
-			warning("Non UTF-8 encoded string:", url_list[i],
-				"-", "Skipped", FALSE);
+	for (; node != NULL; node = node->next) {
+		if (!g_utf8_validate(node->url, -1, NULL)) {
+			warning(FALSE, 3, "Non UTF-8 encoded string: ", node->url, " - Skipped");
 			continue;
 		}
-		feed_title[0] = '\0';
-		for (p = url_list[i]; p < url_list[i] + FILE_NAME_MAXLEN - 1; p = g_utf8_find_next_char(p, NULL)) {
-			if (*p == TITLE_TAG_CHAR) {
-				esc_str = g_uri_escape_string(g_utf8_find_next_char(p, NULL),
-					" AÄääàçéèêÖöôÜüùà'()[]-_|{}/.,;:?!%€£$*+=", TRUE);
-				str_n_cpy(feed_title, esc_str, FEED_TITLE_MAXLEN);
-				g_free(esc_str);
-				*p = '\0';
-				break;
-			} else if (*p == '\0')
-				break;
-		}
-		esc_str = g_uri_escape_string(url_list[i], G_URI_RESERVED_CHARS_GENERIC_DELIMITERS, TRUE);
-		snprintf(tmp, STR_SIZE, opml_item, feed_title, esc_str);
-		g_free(esc_str);
+		esc_str1 = g_uri_escape_string(node->title, " AÄääàçéèêÖöôÜüùà'()[]-_|{}/.,;:?!%€£$*+=", TRUE);
+		esc_str2 = g_uri_escape_string(node->url, G_URI_RESERVED_CHARS_GENERIC_DELIMITERS, TRUE);
+		snprintf(tmp, STR_SIZE, opml_item, esc_str1, esc_str2);
+		g_free(esc_str1);
+		g_free(esc_str2);
 		opml_str = l_str_cat(opml_str, tmp);
 	}
 	return l_str_cat(opml_str, opml_footer);
@@ -311,7 +323,7 @@ int save_str_as_opml_file(const char *str)
 			GTK_STOCK_OK, GTK_RESPONSE_OK,
 			NULL);
 
-	set_news_icon_to_dialog(GTK_WINDOW(dialog));
+	set_tickr_icon_to_dialog(GTK_WINDOW(dialog));
 	gtk_window_set_position(GTK_WINDOW(dialog), GTK_WIN_POS_CENTER);
 
 	g_signal_connect(G_OBJECT(dialog), "key-press-event", G_CALLBACK(esc_key_pressed), NULL);
@@ -330,8 +342,8 @@ int save_str_as_opml_file(const char *str)
 				fclose(fp);
 				exit_status = OK;
 			} else
-				warning("Can't save OPML file:", file_name, "-",
-					strerror(errno), FALSE);
+				warning(FALSE, 3, "Can't save OPML file ", file_name, ": ",
+					strerror(errno));
 		}
 	}
 	gtk_widget_destroy(dialog);
