@@ -1,5 +1,5 @@
 /*
- *	TICKR - GTK-based Feed Reader - Copyright (C) Emmanuel Thomas-Maurin 2009-2011
+ *	TICKR - GTK-based Feed Reader - Copyright (C) Emmanuel Thomas-Maurin 2009-2012
  *	<manutm007@gmail.com>
  *
  * 	This program is free software: you can redistribute it and/or modify
@@ -19,9 +19,8 @@
 #include "tickr.h"
 
 #if USE_GUI
-static gint esc_key_pressed(GtkWidget *dialog2, GdkEventKey *event, gpointer unused)
+static gint esc_key_pressed(GtkWidget *dialog2, GdkEventKey *event)
 {
-	unused = unused;
 	if (event->keyval == GDK_Escape) {
 		gtk_dialog_response(GTK_DIALOG(dialog2), GTK_RESPONSE_CLOSE);
 		return TRUE;
@@ -55,7 +54,7 @@ void open_new_txt_file(Resource *resrc)
 			GTK_STOCK_OK, GTK_RESPONSE_OK,
 			NULL);
 
-	set_news_icon_to_dialog(GTK_WINDOW(dialog));
+	set_tickr_icon_to_dialog(GTK_WINDOW(dialog));
 	gtk_window_set_position(GTK_WINDOW(dialog), GTK_WIN_POS_CENTER);
 
 	g_signal_connect(G_OBJECT(dialog), "key-press-event", G_CALLBACK(esc_key_pressed), NULL);
@@ -72,11 +71,9 @@ void open_new_txt_file(Resource *resrc)
 		str_n_cpy(resrc->id, file_name2, FILE_NAME_MAXLEN);
 		g_free(file_name2);
 
-		env->suspend_rq = TRUE;
 		get_ticker_env()->selection_mode = SINGLE;
 		if ((resource_flag = load_resource(resrc, NULL)) == OK) {
 			env->reload_rq = TRUE;
-			env->suspend_rq = FALSE;
 			break;
 		} else {
 			snprintf(tmp, TMPSTR_SIZE + 1, "load_resource() error %d", resource_flag);
@@ -84,7 +81,6 @@ void open_new_txt_file(Resource *resrc)
 			str_n_cpy(resrc->id, resrc_bak.id, FILE_NAME_MAXLEN);
 			get_ticker_env()->selection_mode = selection_mode_bak;
 			load_resource(resrc, NULL);
-			env->suspend_rq = FALSE;
 		}
 	}
 	gtk_widget_destroy(dialog);
@@ -129,7 +125,7 @@ void help_win()
 			GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
 			NULL);
 
-	set_news_icon_to_dialog(GTK_WINDOW(dialog));
+	set_tickr_icon_to_dialog(GTK_WINDOW(dialog));
 	gtk_window_set_position(GTK_WINDOW(dialog), GTK_WIN_POS_CENTER);
 
 	g_signal_connect(G_OBJECT(dialog), "key-press-event", G_CALLBACK(esc_key_pressed), NULL);
@@ -211,7 +207,7 @@ static gint license_win()
 			GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
 			NULL);
 
-	set_news_icon_to_dialog(GTK_WINDOW(dialog));
+	set_tickr_icon_to_dialog(GTK_WINDOW(dialog));
 	gtk_container_set_border_width(GTK_CONTAINER(dialog), 15);
 	gtk_window_set_position(GTK_WINDOW(dialog), GTK_WIN_POS_NONE);
 
@@ -260,8 +256,9 @@ void about_win()
 
 	license_but = gtk_dialog_add_button(GTK_DIALOG(dialog), "License", GTK_RESPONSE_NONE);
 	close_but = gtk_dialog_add_button(GTK_DIALOG(dialog), GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE);
+	close_but = close_but;	/* to get rid of one compiler warning */
 
-	set_news_icon_to_dialog(GTK_WINDOW(dialog));
+	set_tickr_icon_to_dialog(GTK_WINDOW(dialog));
 	gtk_window_set_position(GTK_WINDOW(dialog), GTK_WIN_POS_CENTER);
 
 	g_signal_connect(G_OBJECT(license_but), "clicked", G_CALLBACK(license_win), NULL);
@@ -273,13 +270,13 @@ void about_win()
 	gtk_container_set_border_width(GTK_CONTAINER(table), 15);
 	gtk_container_add(GTK_CONTAINER(GTK_DIALOG(dialog)->vbox), table);
 
-	image = gtk_image_new_from_file(get_imagefile_full_name_from_name(NEWS_LOGO));
+	image = gtk_image_new_from_file(get_imagefile_full_name_from_name(TICKR_LOGO));
 	gtk_table_attach_defaults(GTK_TABLE(table), image, 0, 1, 0, 1);
 
-	label[0] = gtk_label_new("\n<b>"APP_NAME" version "APP_VERSION_NUMBER" - RSS Feed Reader</b>");
+	label[0] = gtk_label_new("\n<b>"APP_NAME" version "APP_VERSION_NUMBER" - Feed Reader</b>");
 	gtk_label_set_use_markup(GTK_LABEL(label[0]), TRUE);
 	gtk_table_attach_defaults(GTK_TABLE(table), label[0], 0, 1, 1, 2);
-	label[1] = gtk_label_new("<small>Copyright (C) Emmanuel Thomas-Maurin 2009-2011</small>");
+	label[1] = gtk_label_new("<small>Copyright (C) Emmanuel Thomas-Maurin 2009-2012</small>");
 	gtk_label_set_use_markup(GTK_LABEL(label[1]), TRUE);
 	gtk_table_attach_defaults(GTK_TABLE(table), label[1], 0, 1, 2, 3);
 	label[2] = gtk_label_new("<a href=\"mailto:"APP_SUPPORT_EMAIL"\">"APP_SUPPORT_EMAIL"</a>");
@@ -299,7 +296,7 @@ void about_win()
 
 /*
  * info, warning or error
- * === should format txt in case it's a long string ===
+ * === should format text in case it's a long string ===
  */
 void info_win(const char *title, const char *txt, info_type info, gboolean selectable)
 {
@@ -316,8 +313,9 @@ void info_win(const char *title, const char *txt, info_type info, gboolean selec
 			GTK_STOCK_OK, GTK_RESPONSE_OK,
 			NULL);
 
-	set_news_icon_to_dialog(GTK_WINDOW(dialog));
+	set_tickr_icon_to_dialog(GTK_WINDOW(dialog));
 	gtk_window_set_position(GTK_WINDOW(dialog), GTK_WIN_POS_CENTER);
+	gtk_window_set_keep_above(GTK_WINDOW(dialog), TRUE);
 
 	g_signal_connect(G_OBJECT(dialog), "key-press-event", G_CALLBACK(esc_key_pressed), NULL);
 	g_signal_connect(G_OBJECT(dialog), "delete_event", G_CALLBACK(force_quit_dialog), NULL);
@@ -376,8 +374,9 @@ void info_win_wait(const char *txt, int delay)
 
 	win = gtk_window_new(GTK_WINDOW_POPUP);
 
-	set_news_icon_to_dialog(GTK_WINDOW(win));
+	set_tickr_icon_to_dialog(GTK_WINDOW(win));
 	gtk_window_set_position(GTK_WINDOW(win), INFO_WIN_WAIT_POS);
+	gtk_window_set_keep_above(GTK_WINDOW(win), TRUE);
 
 	table = gtk_table_new(1, 3, FALSE);
 	gtk_table_set_col_spacings(GTK_TABLE(table), 10);
@@ -412,7 +411,13 @@ void info_win_wait(const char *txt, int delay)
 	check_main_win_always_on_top();
 }
 
+/* win centered */
 int question_win(const char *txt)
+{
+	return question_win_at(txt, GTK_WIN_POS_CENTER);
+}
+
+int question_win_at(const char *txt, int win_pos)
 {
 	GtkWidget	*dialog, *table, *image, *label[2];
 	gint		response;
@@ -426,8 +431,9 @@ int question_win(const char *txt)
 			GTK_STOCK_YES, GTK_RESPONSE_YES,
 			NULL);
 
-	set_news_icon_to_dialog(GTK_WINDOW(dialog));
-	gtk_window_set_position(GTK_WINDOW(dialog), GTK_WIN_POS_CENTER);
+	set_tickr_icon_to_dialog(GTK_WINDOW(dialog));
+	gtk_window_set_position(GTK_WINDOW(dialog), win_pos);
+	gtk_window_set_keep_above(GTK_WINDOW(dialog), TRUE);
 	/* why always no?
 	gtk_dialog_set_default_response(GTK_DIALOG(dialog), GTK_RESPONSE_NO);*/
 
@@ -452,7 +458,8 @@ int question_win(const char *txt)
 	return ((response == GTK_RESPONSE_YES) ? YES : NO);
 }
 
-void win_with_spinner(spinner_win_mode mode, const char *txt)
+/* this one is buggy as the spinner don't always spin as expected (hmm...) */
+void win_with_spinner(win_with_spinner_mode mode, const char *txt)
 {
 	static GtkWidget	*win;
 	GtkWidget		*hbox, *label;
@@ -466,7 +473,7 @@ void win_with_spinner(spinner_win_mode mode, const char *txt)
 		gtk_window_set_keep_above(GTK_WINDOW(get_ticker_env()->win), FALSE);
 
 		win = gtk_window_new(GTK_WINDOW_POPUP);
-		set_news_icon_to_dialog(GTK_WINDOW(win));
+		set_tickr_icon_to_dialog(GTK_WINDOW(win));
 		gtk_window_set_position(GTK_WINDOW(win), GTK_WIN_POS_CENTER);
 		gtk_window_set_keep_above(GTK_WINDOW(win), TRUE);
 
@@ -506,6 +513,46 @@ void win_with_spinner(spinner_win_mode mode, const char *txt)
 		gtk_widget_destroy(win);
 		check_main_win_always_on_top();
 	} else
-		warning("win_with_spinner():", "Invalid mode", "", "", FALSE);
+		warning(FALSE, 1, "win_with_spinner(): Invalid mode");
+}
+
+void win_with_progress_bar(win_with_progress_bar_mode mode, const char *txt)
+{
+	static GtkWidget	*win, *hbox, *progress_bar;
+
+	if (mode == WIN_WITH_PROGRESS_BAR_OPEN) {
+		gtk_window_set_keep_above(GTK_WINDOW(get_ticker_env()->win), FALSE);
+
+		win = gtk_window_new(GTK_WINDOW_POPUP);
+		set_tickr_icon_to_dialog(GTK_WINDOW(win));
+		gtk_window_set_position(GTK_WINDOW(win), GTK_WIN_POS_CENTER);
+		gtk_window_set_keep_above(GTK_WINDOW(win), TRUE);
+
+		hbox = gtk_hbox_new(FALSE, 0);
+		gtk_container_add(GTK_CONTAINER(GTK_WINDOW(win)), hbox);
+		progress_bar = gtk_progress_bar_new();
+		gtk_container_add(GTK_CONTAINER(GTK_BOX(hbox)), progress_bar);
+		gtk_container_set_border_width(GTK_CONTAINER(GTK_BOX(hbox)), 15);
+
+		gtk_progress_bar_set_text(GTK_PROGRESS_BAR(progress_bar), txt);
+		gtk_progress_bar_set_pulse_step(GTK_PROGRESS_BAR(progress_bar), 0.2);
+
+		gtk_widget_show_all(win);
+
+		/* so that win will popup immediately */
+		while (gtk_events_pending())
+			gtk_main_iteration();
+	} else if (mode == WIN_WITH_PROGRESS_BAR_PULSE) {
+		if (txt != NULL)
+			gtk_progress_bar_set_text(GTK_PROGRESS_BAR(progress_bar), txt);
+		gtk_progress_bar_pulse(GTK_PROGRESS_BAR(progress_bar));
+
+		while (gtk_events_pending())
+			gtk_main_iteration();
+	} else if (mode == WIN_WITH_PROGRESS_BAR_CLOSE) {
+		gtk_widget_destroy(win);
+		check_main_win_always_on_top();
+	} else
+		warning(FALSE, 1, "win_with_spinner(): Invalid mode");
 }
 #endif
