@@ -1,5 +1,5 @@
 /*
- *	TICKR - GTK-based Feed Reader - Copyright (C) Emmanuel Thomas-Maurin 2009-2011
+ *	TICKR - GTK-based Feed Reader - Copyright (C) Emmanuel Thomas-Maurin 2009-2012
  *	<manutm007@gmail.com>
  *
  * 	This program is free software: you can redistribute it and/or modify
@@ -97,16 +97,16 @@ void set_default_options(Params *prm)
 /*
  * load conf file if any & set up - returns 0 if ok
  * store options in a string array and initialize a ptr arrays that matches strings
- * we assume we have up to NOPTIONSMAX options, OPTION_MAXLEN char long max each
+ * we assume we have up to N_OPTION_MAX options, OPTION_MAXLEN char long max each
  */
 int get_config_file_options(Params *prm)
 {
 	FILE		*conf_fp;
-	char		options_array[NOPTIONSMAX][OPTION_MAXLEN + 2], tmp[TMPSTR_SIZE + 1];
-	char		*ptr[NOPTIONSMAX + 1];
+	char		options_array[N_OPTION_MAX][OPTION_MAXLEN + 2];
+	char		*ptr[N_OPTION_MAX + 1];
 	int		i, j = 0;
 
-	if ((conf_fp = g_fopen(get_datafile_full_name_from_name(CONFIGFILE), "rb")) != NULL) {
+	if ((conf_fp = g_fopen(get_datafile_full_name_from_name(CONFIG_FILE), "rb")) != NULL) {
 		/*
 		 * parse conf file
 		 */
@@ -115,13 +115,12 @@ int get_config_file_options(Params *prm)
 			 * here fgets() read OPTION_MAXLEN + 1 char max including
 			 * '\n' then add '\0' (if I'm right...)
 			 */
-			if (i >= NOPTIONSMAX) {
+			if (i >= N_OPTION_MAX) {
 				ptr[i] = NULL;
-				snprintf(tmp, TMPSTR_SIZE + 1,
-					"Too many lines in configuration file: %s "
-					"(max = %d)\nWon't parse further than limit\n",
-					get_datafile_full_name_from_name(CONFIGFILE), NOPTIONSMAX);
-				warning(tmp, "", "", "", FALSE);
+				warning(FALSE, 5, "Too many lines in configuration file: ",
+					get_datafile_full_name_from_name(CONFIG_FILE),
+					"(max = ", itoa2(N_OPTION_MAX), ")"
+					"\nWon't parse further than limit\n");
 				break;
 			}
 			if (fgets(options_array[i], OPTION_MAXLEN + 2, conf_fp) == NULL) {
@@ -140,23 +139,23 @@ int get_config_file_options(Params *prm)
 		fclose(conf_fp);
 	} else
 		fprintf(STD_ERR, "Can't read configuration file: %s - %s\n",
-			get_datafile_full_name_from_name(CONFIGFILE), strerror(errno));
+			get_datafile_full_name_from_name(CONFIG_FILE), strerror(errno));
 	return j;
 }
 
 /*
  * options array parser (NULL terminated ptrs array)
- * we assume we have up to NOPTIONSMAX options, OPTION_MAXLEN char long max each
+ * we assume we have up to N_OPTION_MAX options, OPTION_MAXLEN char long max each
  */
 int parse_options_array(Params *prm, int n_options, const char *option[])
 {
 	int	i, exit_status = OK;
 
-	if (n_options > NOPTIONSMAX) {
-		n_options = NOPTIONSMAX;
+	if (n_options > N_OPTION_MAX) {
+		n_options = N_OPTION_MAX;
 		fprintf(STD_ERR,
 			"Too many options (max = %d) - Won't parse further than limit\n",
-			NOPTIONSMAX);
+			N_OPTION_MAX);
 			exit_status = OPTION_TOO_MANY;
 	}
 	for (i = 0; i < n_options && option[i] != NULL; i++)
@@ -463,12 +462,11 @@ int get_name_value_from_option(Params *prm, const char *option)
 void save_to_config_file(const Params *prm)
 {
 	FILE		*conf_fp;
-	/*char		str1[9 + 1], str2[9 + 1], str3[9 + 1], str4[9 + 1];*/
 	char		fname[FONT_NAME_MAXLEN + 1], fsize[FONT_SIZE_MAXLEN + 1];
 	char		cfname[FONT_NAME_MAXLEN + 1], cfsize[FONT_SIZE_MAXLEN + 1];
 	char		tmp[2 * 1024];
 
-	if ((conf_fp = g_fopen(get_datafile_full_name_from_name(CONFIGFILE), "wb")) != NULL) {
+	if ((conf_fp = g_fopen(get_datafile_full_name_from_name(CONFIG_FILE), "wb")) != NULL) {
 		split_font(prm->font_n_s, fname, fsize);
 		split_font(prm->clock_font_n_s, cfname, cfsize);
 		snprintf(tmp, 2 * 1024, "%s%s%s",
@@ -499,7 +497,6 @@ void save_to_config_file(const Params *prm)
 			"-rssdescription=%c\n"
 			"-rssdescriptiondelimiter=%s\n"
 			"-nitemsperfeed=%d\n"
-			/*"-readinloop=%c\n"*/
 			"-rmtags=%c\n"
 			"-uppercasetext=%c\n"
 			"-homefeed=%s\n"
@@ -551,7 +548,6 @@ void save_to_config_file(const Params *prm)
 			prm->rss_description,
 			prm->rss_description_delimiter,
 			prm->n_items_per_feed,
-			/*prm->read_in_loop,*/
 			prm->strip_html_tags,
 			prm->upper_case_text,
 			prm->homefeed,
@@ -578,9 +574,9 @@ void save_to_config_file(const Params *prm)
 			);
 		fclose(conf_fp);
 	} else
-		warning("Can't save configuration file:",
-			get_datafile_full_name_from_name(CONFIGFILE), "-",
-			strerror(errno), FALSE);
+		warning(FALSE, 4, "Can't save configuration file ",
+			get_datafile_full_name_from_name(CONFIG_FILE), ": ",
+			strerror(errno));
 }
 
 /*
