@@ -1,5 +1,5 @@
 /*
- *	TICKR - GTK-based Feed Reader - Copyright (C) Emmanuel Thomas-Maurin 2009-2011
+ *	TICKR - GTK-based Feed Reader - Copyright (C) Emmanuel Thomas-Maurin 2009-2012
  *	<manutm007@gmail.com>
  *
  * 	This program is free software: you can redistribute it and/or modify
@@ -41,9 +41,8 @@ static GtkWidget	*checkbut_uppercase, *checkbut_nopopups, *checkbut_mouseover;
 static GtkWidget	*checkbut_spchars;
 static GtkWidget	*font_but, *clock_font_but;
 static GtkWidget	*fg_color_but, *bg_color_but, *clock_fg_color_but, *clock_bg_color_but;
-/*static GtkWidget	*rbut_box1, *radio_but1_1, *radio_but1_2;*/
+static GtkWidget	*rbut_box1, *radio_but1_1, *radio_but1_2, *radio_but1_3;
 static GtkWidget	*rbut_box2, *radio_but2_1, *radio_but2_2, *radio_but2_3;
-static GtkWidget	*rbut_box3, *radio_but3_1, *radio_but3_2, *radio_but3_3;
 static GtkWidget	*entry_newpagech, *entry_tabch, *entry_rsstitledel;
 static GtkWidget	*entry_rssdesdel, *entry_linedel, *entry_cutlinedel;
 static GtkWidget	*entry_openlinkcmd, *entry_openlinkargs;
@@ -52,9 +51,8 @@ static GtkObject	*adj_winw, *adj_winh, *adj_shadowoffsetx, *adj_shadowfx;
 static GtkObject	*adj_shadowoffsety, *adj_rssrefresh;
 static GtkObject	*adj_wintransparency, *adj_nitemsperfeed;
 
-static gint esc_key_pressed(GtkWidget *dialog2, GdkEventKey *event, gpointer unused)
+static gint esc_key_pressed(GtkWidget *dialog2, GdkEventKey *event)
 {
-	unused = unused;
 	if (event->keyval == GDK_Escape) {
 		gtk_dialog_response(GTK_DIALOG(dialog2), GTK_RESPONSE_CANCEL);
 		return TRUE;
@@ -70,14 +68,11 @@ static void force_quit_dialog(GtkWidget *dialog2)
 /*
  * ***to be fixed: we want widgets system colors, not these ones***
  */
-static gint use_system_fg_color_ticker(GtkWidget *button, GdkEventKey *event, gpointer unused)
+static gint use_system_fg_color_ticker(GtkWidget *widget)
 {
 	GdkColor color;
 
-	button = button;
-	event = event;
-	unused = unused;
-
+	widget = widget;
 	color = gtk_widget_get_default_style()->fg[0];
 	/*color = gtk_widget_get_style(env->win)->fg[0];*/
 	gtk_color_button_set_color(GTK_COLOR_BUTTON(fg_color_but), &color);
@@ -86,14 +81,11 @@ static gint use_system_fg_color_ticker(GtkWidget *button, GdkEventKey *event, gp
 	return TRUE;
 }
 
-static gint use_system_bg_color_ticker(GtkWidget *button, GdkEventKey *event, gpointer unused)
+static gint use_system_bg_color_ticker(GtkWidget *widget)
 {
 	GdkColor color;
 
-	button = button;
-	event = event;
-	unused = unused;
-
+	widget = widget;
 	color = gtk_widget_get_default_style()->bg[0];
 	/*color = gtk_widget_get_style(env->win)->bg[0];*/
 	gtk_color_button_set_color(GTK_COLOR_BUTTON(bg_color_but), &color);
@@ -102,14 +94,11 @@ static gint use_system_bg_color_ticker(GtkWidget *button, GdkEventKey *event, gp
 	return TRUE;
 }
 
-static gint use_system_fg_color_clock(GtkWidget *button, GdkEventKey *event, gpointer unused)
+static gint use_system_fg_color_clock(GtkWidget *widget)
 {
 	GdkColor color;
 
-	button = button;
-	event = event;
-	unused = unused;
-
+	widget = widget;
 	color = gtk_widget_get_default_style()->fg[0];
 	/*color = gtk_widget_get_style(env->win)->fg[0];*/
 	gtk_color_button_set_color(GTK_COLOR_BUTTON(clock_fg_color_but), &color);
@@ -118,14 +107,11 @@ static gint use_system_fg_color_clock(GtkWidget *button, GdkEventKey *event, gpo
 	return TRUE;
 }
 
-static gint use_system_bg_color_clock(GtkWidget *button, GdkEventKey *event, gpointer unused)
+static gint use_system_bg_color_clock(GtkWidget *widget)
 {
 	GdkColor color;
 
-	button = button;
-	event = event;
-	unused = unused;
-
+	widget = widget;
 	color = gtk_widget_get_default_style()->bg[0];
 	/*color = gtk_widget_get_style(env->win)->bg[0];*/
 	gtk_color_button_set_color(GTK_COLOR_BUTTON(clock_bg_color_but), &color);
@@ -134,26 +120,20 @@ static gint use_system_bg_color_clock(GtkWidget *button, GdkEventKey *event, gpo
 	return TRUE;
 }
 
-static gint move_to_top(GtkWidget *button, GdkEventKey *event, gpointer unused)
+static gint move_to_top(GtkWidget *widget)
 {
-	button = button;
-	event = event;
-	unused = unused;
-
+	widget = widget;
 	gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinbut_winy), 0);
 	return TRUE;
 }
 
-static gint move_to_bottom(GtkWidget *button, GdkEventKey *event, gpointer unused)
+static gint move_to_bottom(GtkWidget *widget)
 {
 	char	font_n_s[FONT_MAXLEN + 1];
 	char	fname[FONT_NAME_MAXLEN + 1], fsize[FONT_SIZE_MAXLEN + 1];
 	gint	requested_font_size, requested_h, y_bottom;
 
-	button = button;
-	event = event;
-	unused = unused;
-
+	widget = widget;
 	/* we need to know requested ticker height */
 	requested_h = (gint)gtk_spin_button_get_value(GTK_SPIN_BUTTON(spinbut_winh));
 	if (requested_h > 0 && requested_h < DRWA_HEIGHT_MIN)
@@ -172,17 +152,15 @@ static gint move_to_bottom(GtkWidget *button, GdkEventKey *event, gpointer unuse
 	y_bottom = env->screen_h - requested_h;
 #ifndef G_OS_WIN32
 	/* how to get taskbar height on linux? */
-	/*info_win_wait("Taskbar height: Will use 25 pixels arbitrary value - "
-			"Please adjust as necessary afterwards", INFO_WIN_WAIT_TIMEOUT);*/
-	warning("Taskbar height: Will use 25 pixels arbitrary value - ",
-			"Please adjust as necessary afterwards", "", "", FALSE);
+	warning(FALSE, 1, "Taskbar height: Will use 25 pixels arbitrary value - "
+			"Please adjust as necessary afterwards");
 	y_bottom -= 25;
 #else
 	if (get_win32_taskbar_height() != -1)
 		y_bottom -= get_win32_taskbar_height();
 	else {
-		warning("Couldn't compute Taskbar height:", "Will use 25 pixels arbitrary value",
-			"-", "Please adjust as necessary afterwards", FALSE);
+		warning(FALSE, 1, "Couldn't compute Taskbar height: Will use 25 pixels arbitrary value"
+			" - Please adjust as necessary afterwards");
 		y_bottom -= 25;
 	}
 #endif
@@ -190,24 +168,18 @@ static gint move_to_bottom(GtkWidget *button, GdkEventKey *event, gpointer unuse
 	return TRUE;
 }
 
-static gint set_full_width(GtkWidget *button, GdkEventKey *event, gpointer unused)
+static gint set_full_width(GtkWidget *widget)
 {
-	button = button;
-	event = event;
-	unused = unused;
-
+	widget = widget;
 	gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinbut_winw), env->screen_w);
-	/* will also locate ticker in left corner */
+	/* will also push ticker in left corner */
 	gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinbut_winx), 0);
 	return TRUE;
 }
 
-static gint get_current_url(GtkWidget *button, GdkEventKey *event, gpointer unused)
+static gint get_current_url(GtkWidget *widget)
 {
-	button = button;
-	event = event;
-	unused = unused;
-
+	widget = widget;
 	gtk_entry_set_text(GTK_ENTRY(entry_homefeed), current_url);
 	return TRUE;
 }
@@ -233,7 +205,7 @@ int modify_params(Params *prm)
 		 	GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
 		 	NULL);
 
-	set_news_icon_to_dialog(GTK_WINDOW(dialog));
+	set_tickr_icon_to_dialog(GTK_WINDOW(dialog));
 	gtk_window_set_position(GTK_WINDOW(dialog), GTK_WIN_POS_CENTER);
 
 	g_signal_connect(G_OBJECT(dialog), "key-press-event", G_CALLBACK(esc_key_pressed), NULL);
@@ -378,7 +350,6 @@ int modify_params(Params *prm)
 	 * win_h
 	 */
 	label[i] = gtk_label_new("Height <small>(Pixels - Override font size if > 0</small>):  ");
-	/*label[i] = gtk_label_new("Height <small>(Pixels - Override font size</small>):  ");*/
 	gtk_label_set_use_markup(GTK_LABEL(label[i]), TRUE);
 	gtk_misc_set_alignment(GTK_MISC(label[i]), 0, 0.5);
 	gtk_table_attach_defaults(GTK_TABLE(table), label[i], COLUMN1, i, i + 1);
@@ -417,12 +388,11 @@ int modify_params(Params *prm)
 	/*
 	 * window transparency
 	 */
-	/*label[i] = gtk_label_new("Window transparency <small>(Actually opacity x 10)</small>:  ");*/
 	label[i] = gtk_label_new("Window opacity <small>(x 10)</small>:  ");
 	gtk_label_set_use_markup(GTK_LABEL(label[i]), TRUE);
 	gtk_misc_set_alignment(GTK_MISC(label[i]), 0, 0.5);
 	gtk_table_attach_defaults(GTK_TABLE(table), label[i], COLUMN1, i, i + 1);
-	/* transparency set from gui ranges from 1 (0.1) to 10 (1.0) / 0 is kind of "useless" */
+	/* transparency set from gui ranges from 1 (0.1) to 10 (1.0) / 0.0 (invisible!) is kind of "useless" */
 	adj_wintransparency = gtk_adjustment_new(prm->win_transparency * 10, 1, 10, 1, 2, 0);
 	spinbut_wintransparency = gtk_spin_button_new(GTK_ADJUSTMENT(adj_wintransparency), 0.0, 0);
 	gtk_table_attach_defaults(GTK_TABLE(table), spinbut_wintransparency, COLUMN2, i, i + 1);
@@ -540,7 +510,6 @@ int modify_params(Params *prm)
 	/*
 	 * rss refresh
 	 */
-	/*label[i] = gtk_label_new("RSS refresh <small>(Minutes - If no TTL / Always apply for files)</small>:  ");*/
 	label[i] = gtk_label_new("Reload delay <small>(Minutes - If no TTL or if text file)</small>:  ");
 	gtk_label_set_use_markup(GTK_LABEL(label[i]), TRUE);
 	gtk_misc_set_alignment(GTK_MISC(label[i]), 0, 0.5);
@@ -612,24 +581,6 @@ int modify_params(Params *prm)
 	spinbut_nitemsperfeed = gtk_spin_button_new(GTK_ADJUSTMENT(adj_nitemsperfeed), 0.0, 0);
 	gtk_table_attach_defaults(GTK_TABLE(table), spinbut_nitemsperfeed, COLUMN2, i, i + 1);
 	i++;
-	/*
-	 * read selection in loop / once
-	 */
-	/*label[i] = gtk_label_new("Read selected feed(s):  ");
-	gtk_label_set_use_markup(GTK_LABEL(label[i]), TRUE);
-	gtk_misc_set_alignment(GTK_MISC(label[i]), 0, 0.5);
-	gtk_table_attach_defaults(GTK_TABLE(table), label[i], COLUMN1, i, i + 1);
-	radio_but1_1 = gtk_radio_button_new_with_label(NULL, "In loop");
-	radio_but1_2 = gtk_radio_button_new_with_label_from_widget(GTK_RADIO_BUTTON(radio_but1_1), "Once");
-	rbut_box1 = gtk_hbox_new(TRUE, 2);
-	gtk_box_pack_start(GTK_BOX(rbut_box1), radio_but1_1, TRUE, TRUE, 0);
-	gtk_box_pack_start(GTK_BOX(rbut_box1), radio_but1_2, TRUE, TRUE, 0);
-	if (prm->read_in_loop == 'y')
-		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio_but1_1), TRUE);
-	else if (prm->read_in_loop == 'n')
-		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio_but1_2), TRUE);
-	gtk_table_attach_defaults(GTK_TABLE(table), rbut_box1, COLUMN2, i, i + 1);
-	i++;*/
 	/*
 	 * remove html tags
 	 */
@@ -662,7 +613,6 @@ int modify_params(Params *prm)
 	 * homefeed / set current feed as homefeed
 	 */
 	hbox5 = gtk_hbox_new(FALSE, 0);
-	/*label[i] = gtk_label_new("'Homefeed' <small>(= Homepage)</small>:  ");*/
 	label[i] = gtk_label_new("Default feed <small>('Homefeed')</small>:  ");
 	gtk_label_set_use_markup(GTK_LABEL(label[i]), TRUE);
 	gtk_misc_set_alignment(GTK_MISC(label[i]), 0, 0.5);
@@ -679,7 +629,6 @@ int modify_params(Params *prm)
 	/*
 	 * "open in browser" command line
 	 */
-	/*label[i] = gtk_label_new("'Open in Browser' command line <small>(May require path)</small>:  ");*/
 	label[i] = gtk_label_new("'Open in Browser' command line:  ");
 	gtk_label_set_use_markup(GTK_LABEL(label[i]), TRUE);
 	gtk_misc_set_alignment(GTK_MISC(label[i]), 0, 0.5);
@@ -708,20 +657,20 @@ int modify_params(Params *prm)
 	gtk_label_set_use_markup(GTK_LABEL(label[i]), TRUE);
 	gtk_misc_set_alignment(GTK_MISC(label[i]), 0, 0.5);
 	gtk_table_attach_defaults(GTK_TABLE(table), label[i], COLUMN1, i, i + 1);
-	radio_but2_1 = gtk_radio_button_new_with_label(NULL, "Left");
-	radio_but2_2 = gtk_radio_button_new_with_label_from_widget(GTK_RADIO_BUTTON(radio_but2_1), "Right");
-	radio_but2_3 = gtk_radio_button_new_with_label_from_widget(GTK_RADIO_BUTTON(radio_but2_1), "None");
-	rbut_box2 = gtk_hbox_new(TRUE, 2);
-	gtk_box_pack_start(GTK_BOX(rbut_box2), radio_but2_1, TRUE, TRUE, 0);
-	gtk_box_pack_start(GTK_BOX(rbut_box2), radio_but2_2, TRUE, TRUE, 0);
-	gtk_box_pack_start(GTK_BOX(rbut_box2), radio_but2_3, TRUE, TRUE, 0);
+	radio_but1_1 = gtk_radio_button_new_with_label(NULL, "Left");
+	radio_but1_2 = gtk_radio_button_new_with_label_from_widget(GTK_RADIO_BUTTON(radio_but1_1), "Right");
+	radio_but1_3 = gtk_radio_button_new_with_label_from_widget(GTK_RADIO_BUTTON(radio_but1_1), "None");
+	rbut_box1 = gtk_hbox_new(TRUE, 2);
+	gtk_box_pack_start(GTK_BOX(rbut_box1), radio_but1_1, TRUE, TRUE, 0);
+	gtk_box_pack_start(GTK_BOX(rbut_box1), radio_but1_2, TRUE, TRUE, 0);
+	gtk_box_pack_start(GTK_BOX(rbut_box1), radio_but1_3, TRUE, TRUE, 0);
 	if (prm->clock == 'l')
-		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio_but2_1), TRUE);
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio_but1_1), TRUE);
 	else if (prm->clock == 'r')
-		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio_but2_2), TRUE);
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio_but1_2), TRUE);
 	else
-		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio_but2_3), TRUE);
-	gtk_table_attach_defaults(GTK_TABLE(table), rbut_box2, COLUMN2, i, i + 1);
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio_but1_3), TRUE);
+	gtk_table_attach_defaults(GTK_TABLE(table), rbut_box1, COLUMN2, i, i + 1);
 	i++;
 	/*
 	 * clock_font
@@ -782,9 +731,9 @@ int modify_params(Params *prm)
 	gtk_table_attach_defaults(GTK_TABLE(table), checkbut_nopopups, COLUMN2, i, i + 1);
 	i++;
 	/*
-	 * pause on mouseover
+	 * pause on mouse-over
 	 */
-	label[i] = gtk_label_new("Pause ticker on mouseover:  ");
+	label[i] = gtk_label_new("Pause ticker on mouse-over:  ");
 	gtk_label_set_use_markup(GTK_LABEL(label[i]), TRUE);
 	gtk_misc_set_alignment(GTK_MISC(label[i]), 0, 0.5);
 	gtk_table_attach_defaults(GTK_TABLE(table), label[i], COLUMN1, i, i + 1);
@@ -802,22 +751,22 @@ int modify_params(Params *prm)
 	gtk_label_set_use_markup(GTK_LABEL(label[i]), TRUE);
 	gtk_misc_set_alignment(GTK_MISC(label[i]), 0, 0.5);
 	gtk_table_attach_defaults(GTK_TABLE(table), label[i], COLUMN1, i, i + 1);
-	radio_but3_1 = gtk_radio_button_new_with_label(NULL, "Speed");
-	radio_but3_2 = gtk_radio_button_new_with_label_from_widget(GTK_RADIO_BUTTON(radio_but3_1), "Feed");
-	radio_but3_3 = gtk_radio_button_new_with_label_from_widget(GTK_RADIO_BUTTON(radio_but3_1), "None");
-	rbut_box3 = gtk_hbox_new(TRUE, 2);
-	gtk_box_pack_start(GTK_BOX(rbut_box3), radio_but3_1, TRUE, TRUE, 0);
-	gtk_box_pack_start(GTK_BOX(rbut_box3), radio_but3_2, TRUE, TRUE, 0);
-	gtk_box_pack_start(GTK_BOX(rbut_box3), radio_but3_3, TRUE, TRUE, 0);
+	radio_but2_1 = gtk_radio_button_new_with_label(NULL, "Speed");
+	radio_but2_2 = gtk_radio_button_new_with_label_from_widget(GTK_RADIO_BUTTON(radio_but2_1), "Feed");
+	radio_but2_3 = gtk_radio_button_new_with_label_from_widget(GTK_RADIO_BUTTON(radio_but2_1), "None");
+	rbut_box2 = gtk_hbox_new(TRUE, 2);
+	gtk_box_pack_start(GTK_BOX(rbut_box2), radio_but2_1, TRUE, TRUE, 0);
+	gtk_box_pack_start(GTK_BOX(rbut_box2), radio_but2_2, TRUE, TRUE, 0);
+	gtk_box_pack_start(GTK_BOX(rbut_box2), radio_but2_3, TRUE, TRUE, 0);
 
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio_but3_1), TRUE);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio_but2_1), TRUE);
 	if (prm->mouse_wheel_scroll == 's')
-		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio_but3_1), TRUE);
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio_but2_1), TRUE);
 	else if (prm->mouse_wheel_scroll == 'f')
-		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio_but3_2), TRUE);
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio_but2_2), TRUE);
 	else
-		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio_but3_3), TRUE);
-	gtk_table_attach_defaults(GTK_TABLE(table), rbut_box3, COLUMN2, i, i + 1);
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio_but2_3), TRUE);
+	gtk_table_attach_defaults(GTK_TABLE(table), rbut_box2, COLUMN2, i, i + 1);
 	i++;
 	/*
 	 * special chars
@@ -983,12 +932,6 @@ int modify_params(Params *prm)
 			/* read n items max per feed */
 			prm->n_items_per_feed = (int)gtk_spin_button_get_value(GTK_SPIN_BUTTON(spinbut_nitemsperfeed));
 
-			/* read selection in loop / once */
-			/*if ((gboolean)gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(radio_but1_1)))
-				prm->read_in_loop = 'y';
-			else if ((gboolean)gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(radio_but1_2)))
-				prm->read_in_loop = 'n';*/
-
 			/* strip html tags */
 			if ((gboolean)gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(checkbut_striptags)))
 				prm->strip_html_tags = 'y';
@@ -1014,9 +957,9 @@ int modify_params(Params *prm)
 				(char *)gtk_entry_get_text(GTK_ENTRY(entry_openlinkargs)), FILE_NAME_MAXLEN);
 
 			/* clock */
-			if ((gboolean)gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(radio_but2_1)))
+			if ((gboolean)gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(radio_but1_1)))
 				prm->clock = 'l';
-			else if ((gboolean)gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(radio_but2_2)))
+			else if ((gboolean)gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(radio_but1_2)))
 				prm->clock = 'r';
 			else
 				prm->clock = 'n';
@@ -1039,16 +982,16 @@ int modify_params(Params *prm)
 			else
 				prm->disable_popups = 'n';
 
-			/* pause on mouseover */
+			/* pause on mouse-over */
 			if ((gboolean)gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(checkbut_mouseover)))
 				prm->pause_on_mouseover = 'y';
 			else
 				prm->pause_on_mouseover = 'n';
 
 			/* mouse wheel scrolling behaviour */
-			if ((gboolean)gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(radio_but3_1)))
+			if ((gboolean)gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(radio_but2_1)))
 				prm->mouse_wheel_scroll = 's';
-			else if ((gboolean)gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(radio_but3_2)))
+			else if ((gboolean)gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(radio_but2_2)))
 				prm->mouse_wheel_scroll = 'f';
 			else
 				prm->mouse_wheel_scroll = 'n';
