@@ -1,5 +1,5 @@
 /*
- *	TICKR - GTK-based Feed Reader - Copyright (C) Emmanuel Thomas-Maurin 2009-2011
+ *	TICKR - GTK-based Feed Reader - Copyright (C) Emmanuel Thomas-Maurin 2009-2012
  *	<manutm007@gmail.com>
  *
  * 	This program is free software: you can redistribute it and/or modify
@@ -22,79 +22,118 @@
 #ifdef G_OS_WIN32
 extern FILE	*stdout_fp, *stderr_fp;
 #endif
-static int	counter = 0;
 
-/* these funcs do nothing in single selection mode -> is that ok? */
+/*
+ * build selection f_list from full feed f_list
+ *
+ * always use get/set_feed_list() and get/set_feed_selection() to access
+ * FList *feed_list and FList *feed_selection defined in tickr_main.c
+ */
+int build_feed_selection_from_feed_list()
+{
+	FList	*new_selection = NULL, *node = get_feed_list();
+
+	if (IS_FLIST(node)) {
+		for (node = f_list_first(node); IS_FLIST(node); node = node->next)
+			if (node->selected)
+				new_selection = f_list_add_at_end(new_selection, node->url, node->title, TRUE);
+		if (IS_FLIST(new_selection)) {
+			new_selection = f_list_first(new_selection);
+			set_feed_selection(new_selection);
+			return OK;
+		} else {
+			set_feed_selection(NULL);
+			return SELECTION_EMPTY;
+		}
+	} else {
+		set_feed_selection(NULL);
+		return SELECTION_ERROR;
+	}
+}
+
+/*
+ * feed_index_in_selection starts at 0
+ * (these funcs do nothing in single selection mode)
+ */
+/* always reload -> ok like that ? */
 void current_feed()
 {
+	FList	*selection = get_feed_selection();
+	int	f_index;
+
 	if (get_ticker_env()->selection_mode == MULTIPLE) {
-		if (counter > 0 )
-			counter--;
+		if ((f_index = f_list_index(selection)) == 0)
+			set_feed_selection(f_list_last(selection));
+		else if (f_index > 0)
+			set_feed_selection(f_list_nth(selection, f_index /* (rank = f_index + 1) - 1 */));
 		get_ticker_env()->reload_rq = TRUE;
 	}
 }
 
+/* always reload -> ok like that ? */
 void first_feed()
 {
 	if (get_ticker_env()->selection_mode == MULTIPLE) {
-		counter = 0;
+		set_feed_selection(f_list_first(get_feed_selection()));
 		get_ticker_env()->reload_rq = TRUE;
 	}
 }
 
+/* always reload -> ok like that ? */
 void last_feed()
 {
 	if (get_ticker_env()->selection_mode == MULTIPLE) {
-		while (get_selected_url_list()[counter] != NULL)
-			counter++;
-		counter--;
+		set_feed_selection(f_list_last(get_feed_selection()));
 		get_ticker_env()->reload_rq = TRUE;
 	}
 }
 
 gboolean previous_feed()
 {
+	FList	*selection = get_feed_selection();
+	int	f_index;
+
 	if (get_ticker_env()->selection_mode == MULTIPLE) {
-		if (counter >= 2 ) {
-			counter -= 2;
+		if ((f_index = f_list_index(selection)) > 1 || f_index == 0) {
+			if (f_index > 1)
+				set_feed_selection(f_list_nth(selection, f_index - 1));
+			else if (f_index == 0)
+				set_feed_selection(f_list_nth(selection, f_list_count(selection) - 1));
 			get_ticker_env()->reload_rq = TRUE;
 			return TRUE;
-		} else {
-			info_win_wait("This is already the first Feed", INFO_WIN_WAIT_TIMEOUT);
-			return FALSE;
-		}
-	} else
-		return FALSE;
+		} else if (f_index == 1)
+			info_win_wait("This is already the first feed", INFO_WIN_WAIT_TIMEOUT);
+	}
+	return FALSE;
 }
 
 gboolean next_feed()
 {
+	FList	*selection = get_feed_selection();
+	int	f_index;
+
 	if (get_ticker_env()->selection_mode == MULTIPLE) {
-		if (get_selected_url_list()[counter] != NULL) {
+		if ((f_index = f_list_index(selection)) > 0) {
 			get_ticker_env()->reload_rq = TRUE;
 			return TRUE;
-		} else {
-			info_win_wait("This is already the last Feed", INFO_WIN_WAIT_TIMEOUT);
-			return FALSE;
-		}
-	} else
-		return FALSE;
+		} else
+			info_win_wait("This is already the last feed", INFO_WIN_WAIT_TIMEOUT);
+	}
+	return FALSE;
 }
 
 /*
- * - single mode: (re)load text file if it exists or rss feed if valid
- * - multiple mode: load sequentially all rss feeds in selected_url[]
+ * - single mode: (re)load resrc->id = text file if it exists or rss feed if valid
+ * - multiple mode: load sequentially all selected feeds in feed list
  *
  * in case of url: load_resource() -> get_feed() -> parse_rss20/rss10/atom_xml_file()
  */
-int load_resource(Resource *resrc, char **selected_urls)
+int load_resource(Resource *resrc, FList *feed_selection)
 {
 #ifdef G_OS_WIN32
 	gchar	*win32_filename;
 #endif
 	int	rss_status, exit_status;
-	char	tmp[256];
-	int	i;
 
 	if (resrc->fp != NULL) {
 		fclose(resrc->fp);
@@ -105,27 +144,22 @@ int load_resource(Resource *resrc, char **selected_urls)
 	resrc->format = RSS_FORMAT_UNDETERMINED;
 
 	if (get_ticker_env()->selection_mode == MULTIPLE) {
-		if (selected_urls[counter] != NULL) {
-			str_n_cpy(resrc->id, selected_urls[counter], FILE_NAME_MAXLEN);
-			counter++;
+		if (IS_FLIST(feed_selection)) {
+			str_n_cpy(resrc->id, feed_selection->url, FILE_NAME_MAXLEN);
+			if (IS_FLIST(feed_selection->next))
+				feed_selection = feed_selection->next;
+			else if (IS_FLIST(f_list_first(feed_selection)))
+				feed_selection = f_list_first(feed_selection);
+			set_feed_selection(feed_selection);
 		} else  {
-			counter = 0;
-			/* we must re-init selected_urls before loading */
-			selected_urls = init_selected_url_list();
-			if ((i = load_selected_url_list((char **)selected_urls)) == SELECTION_ERROR) {
-				warning("No feed selection available", "-",
-					"Switching to single selection mode", "", TRUE);
-				get_ticker_env()->selection_mode = SINGLE;
-				resrc->id[0] = '\0';
-			} else if (i == SELECTION_EMPTY) {
-				warning("No feed selected", "-",
-					"Switching to single selection mode", "", TRUE);
-				get_ticker_env()->selection_mode = SINGLE;
-				resrc->id[0] = '\0';
-			} else {
-				str_n_cpy(resrc->id, selected_urls[counter], FILE_NAME_MAXLEN);
-				counter++;
-			}
+			warning(TRUE, 1, "No feed selected - ",
+				"Switching to single selection mode");
+			get_ticker_env()->selection_mode = SINGLE;
+			resrc->id[0] = '\0';
+			/*warning(TRUE, 1, "No feed selection available - "
+				"Switching to single selection mode");
+			get_ticker_env()->selection_mode = SINGLE;
+			resrc->id[0] = '\0';*/
 		}
 	}
 
@@ -154,9 +188,8 @@ int load_resource(Resource *resrc, char **selected_urls)
 						rss_status != FEED_DOWNLOAD_ERROR &&\
 						rss_status != FEED_FORMAT_ERROR &&\
 						rss_status != CONNECT_TOO_MANY_ERRORS) {
-					snprintf(tmp, 256, "get_feed() error %d", rss_status);
-					warning(tmp, "", "", "",
-						get_ticker_env()->selection_mode == MULTIPLE);
+					warning(get_ticker_env()->selection_mode == MULTIPLE,
+						2, "get_feed() error ", itoa2(rss_status));
 				}
 				resrc->id[0] ='\0';
 				if (rss_status == CONNECT_TOO_MANY_ERRORS)
@@ -178,8 +211,7 @@ int load_resource(Resource *resrc, char **selected_urls)
 
 	if (exit_status == OK) {
 		if (format_resource(resrc) == RESOURCE_FORMAT_ERROR) {
-			big_error(RESOURCE_FORMAT_ERROR,
-				"format_resource() error", "", "", "");
+			big_error(RESOURCE_FORMAT_ERROR, 1, "format_resource() error");
 			exit_status = RESOURCE_FORMAT_ERROR;
 		}
 	}
@@ -249,7 +281,7 @@ int format_resource(Resource *resrc)
 	fseek(resrc->fp, 0, SEEK_SET);
 
 	/* check for lines longer than LINE_MAXLEN and insert newline's if any */
-	tmp_fp = open_new_datafile_with_name(XMLDUMP, "wb+");
+	tmp_fp = open_new_datafile_with_name(XML_DUMP, "wb+");
 	str1 = malloc2(str1_size * sizeof(char));
 	str2 = l_str_new(NULL);
 #ifndef G_OS_WIN32
@@ -287,9 +319,9 @@ int format_resource(Resource *resrc)
 /*
  * *** file names, paths and dirs stuff ***
  */
-void set_news_icon_to_dialog(GtkWindow *dialog)
+void set_tickr_icon_to_dialog(GtkWindow *dialog)
 {
-	gtk_window_set_icon_from_file(dialog, get_imagefile_full_name_from_name(NEWS_ICON), NULL);
+	gtk_window_set_icon_from_file(dialog, get_imagefile_full_name_from_name(TICKR_ICON), NULL);
 }
 
 /* open/create file in data dir from name
@@ -312,9 +344,9 @@ FILE *open_new_datafile_with_name(const char *name, const char *mode_str)
 #endif
 	if ((fp = g_fopen(file_name, mode_str)) == NULL) {
 		if (mode_str[0] == 'w')
-			big_error(CREATE_FILE_ERROR, "Error creating file:", file_name, " - ", strerror(errno));
+			big_error(CREATE_FILE_ERROR, 4, "Error creating file ", file_name, ": ", strerror(errno));
 		else if (mode_str[0] == 'r')
-			big_error(OPEN_FILE_ERROR, "Error opening file:", file_name, " - ", strerror(errno));
+			big_error(OPEN_FILE_ERROR, 4, "Error opening file ", file_name, ": ", strerror(errno));
 	}
 	return fp;
 }
@@ -322,7 +354,7 @@ FILE *open_new_datafile_with_name(const char *name, const char *mode_str)
 /* get full path and name for file in data dir from name
  * data dir = config files, not images files
  */
-const char *get_datafile_full_name_from_name(const char *name)
+char *get_datafile_full_name_from_name(const char *name)
 {
 	static char	file_name[FILE_NAME_MAXLEN + 1];
 #ifdef G_OS_WIN32
@@ -338,11 +370,11 @@ const char *get_datafile_full_name_from_name(const char *name)
 		g_free(win32_filename);
 	}
 #endif
-	return (const char *)file_name;
+	return file_name;
 }
 
 /* now, image files */
-const char *get_imagefile_full_name_from_name(const char *name)
+char *get_imagefile_full_name_from_name(const char *name)
 {
 	static char	file_name[FILE_NAME_MAXLEN + 1];
 #ifdef G_OS_WIN32
@@ -359,29 +391,29 @@ const char *get_imagefile_full_name_from_name(const char *name)
 		g_free(win32_filename);
 	}
 #endif
-	return (const char *)file_name;
+	return file_name;
 }
 
 /* data dir = config files, not images files */
-const char *get_datadir_full_path()
+char *get_datadir_full_path()
 {
 	static char	full_path[TMPSTR_SIZE + 1];
 
 #ifndef G_OS_WIN32
-	snprintf(full_path, TMPSTR_SIZE + 1, "%s%c%s", usr_home_dir(), SEPARATOR_CHAR, NEWS_DIR_NAME);
+	snprintf(full_path, TMPSTR_SIZE + 1, "%s%c%s", usr_home_dir(), SEPARATOR_CHAR, TICKR_DIR_NAME);
 #else
-	snprintf(full_path, TMPSTR_SIZE + 1, "%s%c%s", get_appdata_dir(), SEPARATOR_CHAR, NEWS_DIR_NAME);
+	snprintf(full_path, TMPSTR_SIZE + 1, "%s%c%s", get_appdata_dir(), SEPARATOR_CHAR, TICKR_DIR_NAME);
 #endif
-	return (const char *)full_path;
+	return full_path;
 }
 
-const char *usr_home_dir()
+char *usr_home_dir()
 {
 	static char	str[TMPSTR_SIZE+ 1] = "";
 
 #ifndef G_OS_WIN32
-	return (const char *)str_n_cpy(str, getpwuid(getuid())->pw_dir, TMPSTR_SIZE);
+	return str_n_cpy(str, getpwuid(getuid())->pw_dir, TMPSTR_SIZE);
 #endif
 	/* for win32 version, no home dir - see win32 specific funcs in libetm */
-	return (const char *)str;
+	return str;
 }
